/* widgets.c generated by valac 0.31.1.19-d5143, the Vala compiler
 * generated from widgets.vala, do not modify */

/*
 * Copyright (C) 2013  Paolo Borelli <pborelli@gnome.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <cairo.h>
#include <gdk/gdk.h>
#include <float.h>
#include <math.h>
#include <pango/pango.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>


#define CLOCKS_TYPE_HEADER_BAR (clocks_header_bar_get_type ())
#define CLOCKS_HEADER_BAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_HEADER_BAR, ClocksHeaderBar))
#define CLOCKS_HEADER_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CLOCKS_TYPE_HEADER_BAR, ClocksHeaderBarClass))
#define CLOCKS_IS_HEADER_BAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_HEADER_BAR))
#define CLOCKS_IS_HEADER_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CLOCKS_TYPE_HEADER_BAR))
#define CLOCKS_HEADER_BAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CLOCKS_TYPE_HEADER_BAR, ClocksHeaderBarClass))

typedef struct _ClocksHeaderBar ClocksHeaderBar;
typedef struct _ClocksHeaderBarClass ClocksHeaderBarClass;
typedef struct _ClocksHeaderBarPrivate ClocksHeaderBarPrivate;

#define CLOCKS_HEADER_BAR_TYPE_MODE (clocks_header_bar_mode_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define CLOCKS_TYPE_TITLE_RENDERER (clocks_title_renderer_get_type ())
#define CLOCKS_TITLE_RENDERER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_TITLE_RENDERER, ClocksTitleRenderer))
#define CLOCKS_TITLE_RENDERER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CLOCKS_TYPE_TITLE_RENDERER, ClocksTitleRendererClass))
#define CLOCKS_IS_TITLE_RENDERER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_TITLE_RENDERER))
#define CLOCKS_IS_TITLE_RENDERER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CLOCKS_TYPE_TITLE_RENDERER))
#define CLOCKS_TITLE_RENDERER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CLOCKS_TYPE_TITLE_RENDERER, ClocksTitleRendererClass))

typedef struct _ClocksTitleRenderer ClocksTitleRenderer;
typedef struct _ClocksTitleRendererClass ClocksTitleRendererClass;
typedef struct _ClocksTitleRendererPrivate ClocksTitleRendererPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _gtk_icon_info_free0(var) ((var == NULL) ? NULL : (var = (gtk_icon_info_free (var), NULL)))
#define _cairo_surface_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_surface_destroy (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER (clocks_digital_clock_renderer_get_type ())
#define CLOCKS_DIGITAL_CLOCK_RENDERER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER, ClocksDigitalClockRenderer))
#define CLOCKS_DIGITAL_CLOCK_RENDERER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER, ClocksDigitalClockRendererClass))
#define CLOCKS_IS_DIGITAL_CLOCK_RENDERER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER))
#define CLOCKS_IS_DIGITAL_CLOCK_RENDERER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER))
#define CLOCKS_DIGITAL_CLOCK_RENDERER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER, ClocksDigitalClockRendererClass))

typedef struct _ClocksDigitalClockRenderer ClocksDigitalClockRenderer;
typedef struct _ClocksDigitalClockRendererClass ClocksDigitalClockRendererClass;
typedef struct _ClocksDigitalClockRendererPrivate ClocksDigitalClockRendererPrivate;
#define _pango_layout_line_unref0(var) ((var == NULL) ? NULL : (var = (pango_layout_line_unref (var), NULL)))

#define CLOCKS_TYPE_CONTENT_ITEM (clocks_content_item_get_type ())
#define CLOCKS_CONTENT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_CONTENT_ITEM, ClocksContentItem))
#define CLOCKS_IS_CONTENT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_CONTENT_ITEM))
#define CLOCKS_CONTENT_ITEM_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), CLOCKS_TYPE_CONTENT_ITEM, ClocksContentItemIface))

typedef struct _ClocksContentItem ClocksContentItem;
typedef struct _ClocksContentItemIface ClocksContentItemIface;

#define CLOCKS_TYPE_CONTENT_STORE (clocks_content_store_get_type ())
#define CLOCKS_CONTENT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_CONTENT_STORE, ClocksContentStore))
#define CLOCKS_CONTENT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CLOCKS_TYPE_CONTENT_STORE, ClocksContentStoreClass))
#define CLOCKS_IS_CONTENT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_CONTENT_STORE))
#define CLOCKS_IS_CONTENT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CLOCKS_TYPE_CONTENT_STORE))
#define CLOCKS_CONTENT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CLOCKS_TYPE_CONTENT_STORE, ClocksContentStoreClass))

typedef struct _ClocksContentStore ClocksContentStore;
typedef struct _ClocksContentStoreClass ClocksContentStoreClass;
typedef struct _ClocksContentStorePrivate ClocksContentStorePrivate;
#define _g_variant_type_free0(var) ((var == NULL) ? NULL : (var = (g_variant_type_free (var), NULL)))
#define _g_variant_builder_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_builder_unref (var), NULL)))
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))
#define _g_variant_iter_free0(var) ((var == NULL) ? NULL : (var = (g_variant_iter_free (var), NULL)))

#define CLOCKS_TYPE_ICON_VIEW (clocks_icon_view_get_type ())
#define CLOCKS_ICON_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_ICON_VIEW, ClocksIconView))
#define CLOCKS_ICON_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CLOCKS_TYPE_ICON_VIEW, ClocksIconViewClass))
#define CLOCKS_IS_ICON_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_ICON_VIEW))
#define CLOCKS_IS_ICON_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CLOCKS_TYPE_ICON_VIEW))
#define CLOCKS_ICON_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CLOCKS_TYPE_ICON_VIEW, ClocksIconViewClass))

typedef struct _ClocksIconView ClocksIconView;
typedef struct _ClocksIconViewClass ClocksIconViewClass;
typedef struct _ClocksIconViewPrivate ClocksIconViewPrivate;

#define CLOCKS_ICON_VIEW_TYPE_MODE (clocks_icon_view_mode_get_type ())
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))

#define CLOCKS_TYPE_SELECTION_MENU_BUTTON (clocks_selection_menu_button_get_type ())
#define CLOCKS_SELECTION_MENU_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_SELECTION_MENU_BUTTON, ClocksSelectionMenuButton))
#define CLOCKS_SELECTION_MENU_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CLOCKS_TYPE_SELECTION_MENU_BUTTON, ClocksSelectionMenuButtonClass))
#define CLOCKS_IS_SELECTION_MENU_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_SELECTION_MENU_BUTTON))
#define CLOCKS_IS_SELECTION_MENU_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CLOCKS_TYPE_SELECTION_MENU_BUTTON))
#define CLOCKS_SELECTION_MENU_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CLOCKS_TYPE_SELECTION_MENU_BUTTON, ClocksSelectionMenuButtonClass))

typedef struct _ClocksSelectionMenuButton ClocksSelectionMenuButton;
typedef struct _ClocksSelectionMenuButtonClass ClocksSelectionMenuButtonClass;
typedef struct _ClocksSelectionMenuButtonPrivate ClocksSelectionMenuButtonPrivate;

#define CLOCKS_TYPE_CONTENT_VIEW (clocks_content_view_get_type ())
#define CLOCKS_CONTENT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_CONTENT_VIEW, ClocksContentView))
#define CLOCKS_CONTENT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CLOCKS_TYPE_CONTENT_VIEW, ClocksContentViewClass))
#define CLOCKS_IS_CONTENT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_CONTENT_VIEW))
#define CLOCKS_IS_CONTENT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CLOCKS_TYPE_CONTENT_VIEW))
#define CLOCKS_CONTENT_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CLOCKS_TYPE_CONTENT_VIEW, ClocksContentViewClass))

typedef struct _ClocksContentView ClocksContentView;
typedef struct _ClocksContentViewClass ClocksContentViewClass;
typedef struct _ClocksContentViewPrivate ClocksContentViewPrivate;
typedef struct _Block7Data Block7Data;

#define CLOCKS_TYPE_AM_PM_TOGGLE_BUTTON (clocks_am_pm_toggle_button_get_type ())
#define CLOCKS_AM_PM_TOGGLE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_AM_PM_TOGGLE_BUTTON, ClocksAmPmToggleButton))
#define CLOCKS_AM_PM_TOGGLE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CLOCKS_TYPE_AM_PM_TOGGLE_BUTTON, ClocksAmPmToggleButtonClass))
#define CLOCKS_IS_AM_PM_TOGGLE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_AM_PM_TOGGLE_BUTTON))
#define CLOCKS_IS_AM_PM_TOGGLE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CLOCKS_TYPE_AM_PM_TOGGLE_BUTTON))
#define CLOCKS_AM_PM_TOGGLE_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CLOCKS_TYPE_AM_PM_TOGGLE_BUTTON, ClocksAmPmToggleButtonClass))

typedef struct _ClocksAmPmToggleButton ClocksAmPmToggleButton;
typedef struct _ClocksAmPmToggleButtonClass ClocksAmPmToggleButtonClass;
typedef struct _ClocksAmPmToggleButtonPrivate ClocksAmPmToggleButtonPrivate;

#define CLOCKS_AM_PM_TOGGLE_BUTTON_TYPE_AM_PM (clocks_am_pm_toggle_button_am_pm_get_type ())
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define CLOCKS_TYPE_ANALOG_FRAME (clocks_analog_frame_get_type ())
#define CLOCKS_ANALOG_FRAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLOCKS_TYPE_ANALOG_FRAME, ClocksAnalogFrame))
#define CLOCKS_ANALOG_FRAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CLOCKS_TYPE_ANALOG_FRAME, ClocksAnalogFrameClass))
#define CLOCKS_IS_ANALOG_FRAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLOCKS_TYPE_ANALOG_FRAME))
#define CLOCKS_IS_ANALOG_FRAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CLOCKS_TYPE_ANALOG_FRAME))
#define CLOCKS_ANALOG_FRAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CLOCKS_TYPE_ANALOG_FRAME, ClocksAnalogFrameClass))

typedef struct _ClocksAnalogFrame ClocksAnalogFrame;
typedef struct _ClocksAnalogFrameClass ClocksAnalogFrameClass;
typedef struct _ClocksAnalogFramePrivate ClocksAnalogFramePrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ClocksHeaderBar {
	GtkHeaderBar parent_instance;
	ClocksHeaderBarPrivate * priv;
};

struct _ClocksHeaderBarClass {
	GtkHeaderBarClass parent_class;
};

typedef enum  {
	CLOCKS_HEADER_BAR_MODE_NORMAL,
	CLOCKS_HEADER_BAR_MODE_SELECTION,
	CLOCKS_HEADER_BAR_MODE_STANDALONE
} ClocksHeaderBarMode;

struct _ClocksHeaderBarPrivate {
	ClocksHeaderBarMode _mode;
};

struct _ClocksTitleRenderer {
	GtkCellRendererText parent_instance;
	ClocksTitleRendererPrivate * priv;
};

struct _ClocksTitleRendererClass {
	GtkCellRendererTextClass parent_class;
};

struct _ClocksTitleRendererPrivate {
	gint ICON_XOFF;
	gint ICON_YOFF;
	gint ICON_SIZE;
	gchar* _title_icon;
	gchar* _title;
};

struct _ClocksDigitalClockRenderer {
	GtkCellRendererPixbuf parent_instance;
	ClocksDigitalClockRendererPrivate * priv;
};

struct _ClocksDigitalClockRendererClass {
	GtkCellRendererPixbufClass parent_class;
};

struct _ClocksDigitalClockRendererPrivate {
	gchar* _text;
	gchar* _subtext;
	gchar* _css_class;
	gboolean _checked;
	gboolean _toggle_visible;
	gboolean _selectable;
};

struct _ClocksContentItemIface {
	GTypeInterface parent_iface;
	void (*get_thumb_properties) (ClocksContentItem* self, gchar** text, gchar** subtext, GdkPixbuf** pixbuf, gchar** css_class);
	void (*serialize) (ClocksContentItem* self, GVariantBuilder* builder);
	const gchar* (*get_name) (ClocksContentItem* self);
	void (*set_name) (ClocksContentItem* self, const gchar* value);
	const gchar* (*get_title_icon) (ClocksContentItem* self);
	void (*set_title_icon) (ClocksContentItem* self, const gchar* value);
	gboolean (*get_selectable) (ClocksContentItem* self);
	void (*set_selectable) (ClocksContentItem* self, gboolean value);
	gboolean (*get_selected) (ClocksContentItem* self);
	void (*set_selected) (ClocksContentItem* self, gboolean value);
};

struct _ClocksContentStore {
	GObject parent_instance;
	ClocksContentStorePrivate * priv;
};

struct _ClocksContentStoreClass {
	GObjectClass parent_class;
};

struct _ClocksContentStorePrivate {
	GListStore* store;
	GCompareDataFunc sort_func;
	gpointer sort_func_target;
	GDestroyNotify sort_func_target_destroy_notify;
};

typedef void (*ClocksContentStoreForeachFunc) (ClocksContentItem* item, void* user_data);
typedef gboolean (*ClocksContentStoreFindFunc) (ClocksContentItem* item, void* user_data);
typedef ClocksContentItem* (*ClocksContentStoreDeserializeItemFunc) (GVariant* v, void* user_data);
struct _ClocksIconView {
	GtkIconView parent_instance;
	ClocksIconViewPrivate * priv;
};

struct _ClocksIconViewClass {
	GtkIconViewClass parent_class;
};

typedef enum  {
	CLOCKS_ICON_VIEW_MODE_NORMAL,
	CLOCKS_ICON_VIEW_MODE_SELECTION
} ClocksIconViewMode;

struct _ClocksIconViewPrivate {
	ClocksIconViewMode _mode;
};

struct _ClocksSelectionMenuButton {
	GtkMenuButton parent_instance;
	ClocksSelectionMenuButtonPrivate * priv;
};

struct _ClocksSelectionMenuButtonClass {
	GtkMenuButtonClass parent_class;
};

struct _ClocksSelectionMenuButtonPrivate {
	guint _n_items;
	GtkLabel* menubutton_label;
};

struct _ClocksContentView {
	GtkBin parent_instance;
	ClocksContentViewPrivate * priv;
};

struct _ClocksContentViewClass {
	GtkBinClass parent_class;
};

struct _ClocksContentViewPrivate {
	gboolean _can_select;
	ClocksContentStore* model;
	ClocksIconView* icon_view;
	GtkButton* select_button;
	GtkButton* cancel_button;
	ClocksSelectionMenuButton* selection_menubutton;
	GtkGrid* grid;
	GtkButton* delete_button;
	ClocksHeaderBar* header_bar;
};

struct _Block7Data {
	int _ref_count_;
	ClocksContentView* self;
	GtkActionBar* action_bar;
};

struct _ClocksAmPmToggleButton {
	GtkButton parent_instance;
	ClocksAmPmToggleButtonPrivate * priv;
};

struct _ClocksAmPmToggleButtonClass {
	GtkButtonClass parent_class;
};

typedef enum  {
	CLOCKS_AM_PM_TOGGLE_BUTTON_AM_PM_AM,
	CLOCKS_AM_PM_TOGGLE_BUTTON_AM_PM_PM
} ClocksAmPmToggleButtonAmPm;

struct _ClocksAmPmToggleButtonPrivate {
	ClocksAmPmToggleButtonAmPm _choice;
	GtkStack* stack;
	GtkLabel* am_label;
	GtkLabel* pm_label;
};

struct _ClocksAnalogFrame {
	GtkBin parent_instance;
	ClocksAnalogFramePrivate * priv;
};

struct _ClocksAnalogFrameClass {
	GtkBinClass parent_class;
	void (*draw_progress) (ClocksAnalogFrame* self, cairo_t* cr, gint center_x, gint center_y, gint radius);
};


static gpointer clocks_header_bar_parent_class = NULL;
static gpointer clocks_title_renderer_parent_class = NULL;
static gpointer clocks_digital_clock_renderer_parent_class = NULL;
static gpointer clocks_content_store_parent_class = NULL;
static GListModelInterface* clocks_content_store_g_list_model_parent_iface = NULL;
static gpointer clocks_icon_view_parent_class = NULL;
static gpointer clocks_selection_menu_button_parent_class = NULL;
static gpointer clocks_content_view_parent_class = NULL;
static gpointer clocks_am_pm_toggle_button_parent_class = NULL;
static gpointer clocks_analog_frame_parent_class = NULL;

GType clocks_header_bar_get_type (void) G_GNUC_CONST;
GType clocks_header_bar_mode_get_type (void) G_GNUC_CONST;
#define CLOCKS_HEADER_BAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CLOCKS_TYPE_HEADER_BAR, ClocksHeaderBarPrivate))
enum  {
	CLOCKS_HEADER_BAR_DUMMY_PROPERTY,
	CLOCKS_HEADER_BAR_MODE
};
void clocks_header_bar_clear (ClocksHeaderBar* self);
ClocksHeaderBar* clocks_header_bar_new (void);
ClocksHeaderBar* clocks_header_bar_construct (GType object_type);
ClocksHeaderBarMode clocks_header_bar_get_mode (ClocksHeaderBar* self);
void clocks_header_bar_set_mode (ClocksHeaderBar* self, ClocksHeaderBarMode value);
static void clocks_header_bar_finalize (GObject* obj);
static void _vala_clocks_header_bar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_clocks_header_bar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType clocks_title_renderer_get_type (void) G_GNUC_CONST;
#define CLOCKS_TITLE_RENDERER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CLOCKS_TYPE_TITLE_RENDERER, ClocksTitleRendererPrivate))
enum  {
	CLOCKS_TITLE_RENDERER_DUMMY_PROPERTY,
	CLOCKS_TITLE_RENDERER_TITLE,
	CLOCKS_TITLE_RENDERER_TITLE_ICON
};
ClocksTitleRenderer* clocks_title_renderer_new (void);
ClocksTitleRenderer* clocks_title_renderer_construct (GType object_type);
static void clocks_title_renderer_real_render (GtkCellRenderer* base, cairo_t* cr, GtkWidget* widget, GdkRectangle* background_area, GdkRectangle* cell_area, GtkCellRendererState flags);
const gchar* clocks_title_renderer_get_title_icon (ClocksTitleRenderer* self);
const gchar* clocks_title_renderer_get_title (ClocksTitleRenderer* self);
void clocks_title_renderer_set_title (ClocksTitleRenderer* self, const gchar* value);
void clocks_title_renderer_set_title_icon (ClocksTitleRenderer* self, const gchar* value);
static void clocks_title_renderer_finalize (GObject* obj);
static void _vala_clocks_title_renderer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_clocks_title_renderer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType clocks_digital_clock_renderer_get_type (void) G_GNUC_CONST;
#define CLOCKS_DIGITAL_CLOCK_RENDERER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER, ClocksDigitalClockRendererPrivate))
enum  {
	CLOCKS_DIGITAL_CLOCK_RENDERER_DUMMY_PROPERTY,
	CLOCKS_DIGITAL_CLOCK_RENDERER_TEXT,
	CLOCKS_DIGITAL_CLOCK_RENDERER_SUBTEXT,
	CLOCKS_DIGITAL_CLOCK_RENDERER_CSS_CLASS,
	CLOCKS_DIGITAL_CLOCK_RENDERER_CHECKED,
	CLOCKS_DIGITAL_CLOCK_RENDERER_TOGGLE_VISIBLE,
	CLOCKS_DIGITAL_CLOCK_RENDERER_SELECTABLE
};
#define CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_SIZE 256
#define CLOCKS_DIGITAL_CLOCK_RENDERER_CHECK_ICON_SIZE 40
#define CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_MARGIN (CLOCKS_DIGITAL_CLOCK_RENDERER_CHECK_ICON_SIZE / 4)
#define CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_MARGIN_BOTTOM (CLOCKS_DIGITAL_CLOCK_RENDERER_CHECK_ICON_SIZE / 8)
ClocksDigitalClockRenderer* clocks_digital_clock_renderer_new (void);
ClocksDigitalClockRenderer* clocks_digital_clock_renderer_construct (GType object_type);
static void clocks_digital_clock_renderer_real_render (GtkCellRenderer* base, cairo_t* cr, GtkWidget* widget, GdkRectangle* background_area, GdkRectangle* cell_area, GtkCellRendererState flags);
const gchar* clocks_digital_clock_renderer_get_css_class (ClocksDigitalClockRenderer* self);
const gchar* clocks_digital_clock_renderer_get_text (ClocksDigitalClockRenderer* self);
const gchar* clocks_digital_clock_renderer_get_subtext (ClocksDigitalClockRenderer* self);
gboolean clocks_digital_clock_renderer_get_selectable (ClocksDigitalClockRenderer* self);
gboolean clocks_digital_clock_renderer_get_toggle_visible (ClocksDigitalClockRenderer* self);
gboolean clocks_digital_clock_renderer_get_checked (ClocksDigitalClockRenderer* self);
void clocks_digital_clock_renderer_set_text (ClocksDigitalClockRenderer* self, const gchar* value);
void clocks_digital_clock_renderer_set_subtext (ClocksDigitalClockRenderer* self, const gchar* value);
void clocks_digital_clock_renderer_set_css_class (ClocksDigitalClockRenderer* self, const gchar* value);
void clocks_digital_clock_renderer_set_checked (ClocksDigitalClockRenderer* self, gboolean value);
void clocks_digital_clock_renderer_set_toggle_visible (ClocksDigitalClockRenderer* self, gboolean value);
void clocks_digital_clock_renderer_set_selectable (ClocksDigitalClockRenderer* self, gboolean value);
static void clocks_digital_clock_renderer_finalize (GObject* obj);
static void _vala_clocks_digital_clock_renderer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_clocks_digital_clock_renderer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType clocks_content_item_get_type (void) G_GNUC_CONST;
void clocks_content_item_get_thumb_properties (ClocksContentItem* self, gchar** text, gchar** subtext, GdkPixbuf** pixbuf, gchar** css_class);
void clocks_content_item_serialize (ClocksContentItem* self, GVariantBuilder* builder);
const gchar* clocks_content_item_get_name (ClocksContentItem* self);
void clocks_content_item_set_name (ClocksContentItem* self, const gchar* value);
const gchar* clocks_content_item_get_title_icon (ClocksContentItem* self);
void clocks_content_item_set_title_icon (ClocksContentItem* self, const gchar* value);
gboolean clocks_content_item_get_selectable (ClocksContentItem* self);
void clocks_content_item_set_selectable (ClocksContentItem* self, gboolean value);
gboolean clocks_content_item_get_selected (ClocksContentItem* self);
void clocks_content_item_set_selected (ClocksContentItem* self, gboolean value);
GType clocks_content_store_get_type (void) G_GNUC_CONST;
#define CLOCKS_CONTENT_STORE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CLOCKS_TYPE_CONTENT_STORE, ClocksContentStorePrivate))
enum  {
	CLOCKS_CONTENT_STORE_DUMMY_PROPERTY
};
ClocksContentStore* clocks_content_store_new (void);
ClocksContentStore* clocks_content_store_construct (GType object_type);
static void __lambda10_ (ClocksContentStore* self, guint position, guint removed, guint added);
static void ___lambda10__g_list_model_items_changed (GListModel* _sender, guint position, guint removed, guint added, gpointer self);
static GType clocks_content_store_real_get_item_type (GListModel* base);
static guint clocks_content_store_real_get_n_items (GListModel* base);
static GObject* clocks_content_store_real_get_item (GListModel* base, guint position);
void clocks_content_store_set_sorting (ClocksContentStore* self, GCompareDataFunc sort, void* sort_target, GDestroyNotify sort_target_destroy_notify);
static void clocks_content_store_on_item_selection_toggle (ClocksContentStore* self, GObject* o, GParamSpec* p);
void clocks_content_store_add (ClocksContentStore* self, ClocksContentItem* item);
static void _clocks_content_store_on_item_selection_toggle_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void clocks_content_store_foreach (ClocksContentStore* self, ClocksContentStoreForeachFunc func, void* func_target);
ClocksContentItem* clocks_content_store_find (ClocksContentStore* self, ClocksContentStoreFindFunc func, void* func_target);
guint clocks_content_store_get_n_selected (ClocksContentStore* self);
void clocks_content_store_delete_selected (ClocksContentStore* self);
static void _vala_array_add2 (GObject*** array, int* length, int* size, GObject* value);
static void clocks_content_store_select_unselect_all (ClocksContentStore* self, gboolean select);
void clocks_content_store_select_all (ClocksContentStore* self);
void clocks_content_store_unselect_all (ClocksContentStore* self);
GVariant* clocks_content_store_serialize (ClocksContentStore* self);
void clocks_content_store_deserialize (ClocksContentStore* self, GVariant* variant, ClocksContentStoreDeserializeItemFunc deserialize_item, void* deserialize_item_target);
static void clocks_content_store_finalize (GObject* obj);
GType clocks_icon_view_get_type (void) G_GNUC_CONST;
GType clocks_icon_view_mode_get_type (void) G_GNUC_CONST;
#define CLOCKS_ICON_VIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CLOCKS_TYPE_ICON_VIEW, ClocksIconViewPrivate))
enum  {
	CLOCKS_ICON_VIEW_DUMMY_PROPERTY,
	CLOCKS_ICON_VIEW_MODE
};
ClocksIconView* clocks_icon_view_new (void);
ClocksIconView* clocks_icon_view_construct (GType object_type);
static void __lambda11_ (ClocksIconView* self, GtkCellLayout* column, GtkCellRenderer* cell, GtkTreeModel* model, GtkTreeIter* iter);
ClocksIconViewMode clocks_icon_view_get_mode (ClocksIconView* self);
static void ___lambda11__gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self);
static void __lambda12_ (ClocksIconView* self, GtkCellLayout* column, GtkCellRenderer* cell, GtkTreeModel* model, GtkTreeIter* iter);
static void ___lambda12__gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self);
static gboolean clocks_icon_view_real_button_press_event (GtkWidget* base, GdkEventButton* event);
void clocks_icon_view_set_mode (ClocksIconView* self, ClocksIconViewMode value);
void clocks_icon_view_add_item (ClocksIconView* self, GObject* item);
void clocks_icon_view_clear (ClocksIconView* self);
static void clocks_icon_view_finalize (GObject* obj);
static void _vala_clocks_icon_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_clocks_icon_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType clocks_selection_menu_button_get_type (void) G_GNUC_CONST;
#define CLOCKS_SELECTION_MENU_BUTTON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CLOCKS_TYPE_SELECTION_MENU_BUTTON, ClocksSelectionMenuButtonPrivate))
enum  {
	CLOCKS_SELECTION_MENU_BUTTON_DUMMY_PROPERTY,
	CLOCKS_SELECTION_MENU_BUTTON_N_ITEMS
};
ClocksSelectionMenuButton* clocks_selection_menu_button_new (void);
ClocksSelectionMenuButton* clocks_selection_menu_button_construct (GType object_type);
guint clocks_selection_menu_button_get_n_items (ClocksSelectionMenuButton* self);
void clocks_selection_menu_button_set_n_items (ClocksSelectionMenuButton* self, guint value);
static void clocks_selection_menu_button_finalize (GObject* obj);
static void _vala_clocks_selection_menu_button_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_clocks_selection_menu_button_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType clocks_content_view_get_type (void) G_GNUC_CONST;
#define CLOCKS_CONTENT_VIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CLOCKS_TYPE_CONTENT_VIEW, ClocksContentViewPrivate))
enum  {
	CLOCKS_CONTENT_VIEW_DUMMY_PROPERTY
};
void clocks_content_view_bind_model (ClocksContentView* self, ClocksContentStore* store);
static void __lambda13_ (ClocksContentView* self, guint position, guint removed, guint added);
static gboolean __lambda14_ (ClocksContentView* self, ClocksContentItem* i);
static gboolean ___lambda14__clocks_content_store_find_func (ClocksContentItem* item, gpointer self);
static void clocks_content_view_set_can_select (ClocksContentView* self, gboolean value);
static void __lambda15_ (ClocksContentView* self, ClocksContentItem* item);
static void ___lambda15__clocks_content_store_foreach_func (ClocksContentItem* item, gpointer self);
static void ___lambda13__g_list_model_items_changed (GListModel* _sender, guint position, guint removed, guint added, gpointer self);
static void __lambda16_ (ClocksContentView* self);
static void ___lambda16__clocks_content_store_selection_changed (ClocksContentStore* _sender, gpointer self);
void clocks_content_view_select_all (ClocksContentView* self);
void clocks_content_view_unselect_all (ClocksContentView* self);
gboolean clocks_content_view_escape_pressed (ClocksContentView* self);
void clocks_content_view_set_header_bar (ClocksContentView* self, ClocksHeaderBar* bar);
static void __lambda17_ (ClocksContentView* self);
static void ___lambda17__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda18_ (ClocksContentView* self);
static void ___lambda18__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda19_ (ClocksContentView* self);
static void ___lambda19__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void clocks_content_view_update_header_bar (ClocksContentView* self);
static gboolean clocks_content_view_get_can_select (ClocksContentView* self);
ClocksContentView* clocks_content_view_new (void);
ClocksContentView* clocks_content_view_construct (GType object_type);
static GObject * clocks_content_view_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
static void _clocks_content_view___lambda20_ (ClocksContentView* self);
static void __clocks_content_view___lambda20__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void _clocks_content_view___lambda21_ (Block7Data* _data7_);
static void __clocks_content_view___lambda21__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _clocks_content_view___lambda22_ (ClocksContentView* self, GtkTreePath* path);
static void __clocks_content_view___lambda22__gtk_icon_view_item_activated (GtkIconView* _sender, GtkTreePath* path, gpointer self);
static void clocks_content_view_finalize (GObject* obj);
static void _vala_clocks_content_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_clocks_content_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType clocks_am_pm_toggle_button_get_type (void) G_GNUC_CONST;
GType clocks_am_pm_toggle_button_am_pm_get_type (void) G_GNUC_CONST;
#define CLOCKS_AM_PM_TOGGLE_BUTTON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CLOCKS_TYPE_AM_PM_TOGGLE_BUTTON, ClocksAmPmToggleButtonPrivate))
enum  {
	CLOCKS_AM_PM_TOGGLE_BUTTON_DUMMY_PROPERTY,
	CLOCKS_AM_PM_TOGGLE_BUTTON_CHOICE
};
ClocksAmPmToggleButton* clocks_am_pm_toggle_button_new (void);
ClocksAmPmToggleButton* clocks_am_pm_toggle_button_construct (GType object_type);
static void __lambda41_ (ClocksAmPmToggleButton* self);
ClocksAmPmToggleButtonAmPm clocks_am_pm_toggle_button_get_choice (ClocksAmPmToggleButton* self);
void clocks_am_pm_toggle_button_set_choice (ClocksAmPmToggleButton* self, ClocksAmPmToggleButtonAmPm value);
static void ___lambda41__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void clocks_am_pm_toggle_button_finalize (GObject* obj);
static void _vala_clocks_am_pm_toggle_button_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_clocks_am_pm_toggle_button_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType clocks_analog_frame_get_type (void) G_GNUC_CONST;
enum  {
	CLOCKS_ANALOG_FRAME_DUMMY_PROPERTY
};
#define CLOCKS_ANALOG_FRAME_LINE_WIDTH 6
#define CLOCKS_ANALOG_FRAME_RADIUS_PAD 48
static gint clocks_analog_frame_calculate_diameter (ClocksAnalogFrame* self);
static void clocks_analog_frame_real_get_preferred_width (GtkWidget* base, gint* min_w, gint* natural_w);
static void clocks_analog_frame_real_get_preferred_height (GtkWidget* base, gint* min_h, gint* natural_h);
static void clocks_analog_frame_real_size_allocate (GtkWidget* base, GtkAllocation* allocation);
static gboolean clocks_analog_frame_real_draw (GtkWidget* base, cairo_t* cr);
void clocks_analog_frame_draw_progress (ClocksAnalogFrame* self, cairo_t* cr, gint center_x, gint center_y, gint radius);
static void clocks_analog_frame_real_draw_progress (ClocksAnalogFrame* self, cairo_t* cr, gint center_x, gint center_y, gint radius);
ClocksAnalogFrame* clocks_analog_frame_new (void);
ClocksAnalogFrame* clocks_analog_frame_construct (GType object_type);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


GType clocks_header_bar_mode_get_type (void) {
	static volatile gsize clocks_header_bar_mode_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_header_bar_mode_type_id__volatile)) {
		static const GEnumValue values[] = {{CLOCKS_HEADER_BAR_MODE_NORMAL, "CLOCKS_HEADER_BAR_MODE_NORMAL", "normal"}, {CLOCKS_HEADER_BAR_MODE_SELECTION, "CLOCKS_HEADER_BAR_MODE_SELECTION", "selection"}, {CLOCKS_HEADER_BAR_MODE_STANDALONE, "CLOCKS_HEADER_BAR_MODE_STANDALONE", "standalone"}, {0, NULL, NULL}};
		GType clocks_header_bar_mode_type_id;
		clocks_header_bar_mode_type_id = g_enum_register_static ("ClocksHeaderBarMode", values);
		g_once_init_leave (&clocks_header_bar_mode_type_id__volatile, clocks_header_bar_mode_type_id);
	}
	return clocks_header_bar_mode_type_id__volatile;
}


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


void clocks_header_bar_clear (ClocksHeaderBar* self) {
	GList* _tmp0_ = NULL;
	g_return_if_fail (self != NULL);
	gtk_header_bar_set_custom_title ((GtkHeaderBar*) self, NULL);
	_tmp0_ = gtk_container_get_children ((GtkContainer*) self);
	{
		GList* w_collection = NULL;
		GList* w_it = NULL;
		w_collection = _tmp0_;
		for (w_it = w_collection; w_it != NULL; w_it = w_it->next) {
			GtkWidget* _tmp1_ = NULL;
			GtkWidget* w = NULL;
			_tmp1_ = _g_object_ref0 ((GtkWidget*) w_it->data);
			w = _tmp1_;
			{
				GtkWidget* _tmp2_ = NULL;
				_tmp2_ = w;
				gtk_widget_hide (_tmp2_);
				_g_object_unref0 (w);
			}
		}
		_g_list_free0 (w_collection);
	}
}


ClocksHeaderBar* clocks_header_bar_construct (GType object_type) {
	ClocksHeaderBar * self = NULL;
	self = (ClocksHeaderBar*) g_object_new (object_type, NULL);
	return self;
}


ClocksHeaderBar* clocks_header_bar_new (void) {
	return clocks_header_bar_construct (CLOCKS_TYPE_HEADER_BAR);
}


ClocksHeaderBarMode clocks_header_bar_get_mode (ClocksHeaderBar* self) {
	ClocksHeaderBarMode result;
	ClocksHeaderBarMode _tmp0_ = 0;
	g_return_val_if_fail (self != NULL, 0);
	_tmp0_ = self->priv->_mode;
	result = _tmp0_;
	return result;
}


void clocks_header_bar_set_mode (ClocksHeaderBar* self, ClocksHeaderBarMode value) {
	ClocksHeaderBarMode _tmp0_ = 0;
	ClocksHeaderBarMode _tmp1_ = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_mode;
	_tmp1_ = value;
	if (_tmp0_ != _tmp1_) {
		ClocksHeaderBarMode _tmp2_ = 0;
		ClocksHeaderBarMode _tmp3_ = 0;
		_tmp2_ = value;
		self->priv->_mode = _tmp2_;
		_tmp3_ = self->priv->_mode;
		if (_tmp3_ == CLOCKS_HEADER_BAR_MODE_SELECTION) {
			GtkStyleContext* _tmp4_ = NULL;
			_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) self);
			gtk_style_context_add_class (_tmp4_, "selection-mode");
		} else {
			GtkStyleContext* _tmp5_ = NULL;
			_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) self);
			gtk_style_context_remove_class (_tmp5_, "selection-mode");
		}
		g_object_notify ((GObject*) self, "mode");
	}
}


static void clocks_header_bar_class_init (ClocksHeaderBarClass * klass) {
	clocks_header_bar_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ClocksHeaderBarPrivate));
	G_OBJECT_CLASS (klass)->get_property = _vala_clocks_header_bar_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_clocks_header_bar_set_property;
	G_OBJECT_CLASS (klass)->finalize = clocks_header_bar_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_HEADER_BAR_MODE, g_param_spec_enum ("mode", "mode", "mode", CLOCKS_HEADER_BAR_TYPE_MODE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void clocks_header_bar_instance_init (ClocksHeaderBar * self) {
	self->priv = CLOCKS_HEADER_BAR_GET_PRIVATE (self);
}


static void clocks_header_bar_finalize (GObject* obj) {
	ClocksHeaderBar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CLOCKS_TYPE_HEADER_BAR, ClocksHeaderBar);
	G_OBJECT_CLASS (clocks_header_bar_parent_class)->finalize (obj);
}


GType clocks_header_bar_get_type (void) {
	static volatile gsize clocks_header_bar_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_header_bar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ClocksHeaderBarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) clocks_header_bar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ClocksHeaderBar), 0, (GInstanceInitFunc) clocks_header_bar_instance_init, NULL };
		GType clocks_header_bar_type_id;
		clocks_header_bar_type_id = g_type_register_static (gtk_header_bar_get_type (), "ClocksHeaderBar", &g_define_type_info, 0);
		g_once_init_leave (&clocks_header_bar_type_id__volatile, clocks_header_bar_type_id);
	}
	return clocks_header_bar_type_id__volatile;
}


static void _vala_clocks_header_bar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ClocksHeaderBar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_HEADER_BAR, ClocksHeaderBar);
	switch (property_id) {
		case CLOCKS_HEADER_BAR_MODE:
		g_value_set_enum (value, clocks_header_bar_get_mode (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_clocks_header_bar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ClocksHeaderBar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_HEADER_BAR, ClocksHeaderBar);
	switch (property_id) {
		case CLOCKS_HEADER_BAR_MODE:
		clocks_header_bar_set_mode (self, g_value_get_enum (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


ClocksTitleRenderer* clocks_title_renderer_construct (GType object_type) {
	ClocksTitleRenderer * self = NULL;
	self = (ClocksTitleRenderer*) g_object_new (object_type, NULL);
	self->priv->ICON_YOFF = 5;
	self->priv->ICON_XOFF = 25;
	self->priv->ICON_SIZE = 18;
	return self;
}


ClocksTitleRenderer* clocks_title_renderer_new (void) {
	return clocks_title_renderer_construct (CLOCKS_TYPE_TITLE_RENDERER);
}


static void clocks_title_renderer_real_render (GtkCellRenderer* base, cairo_t* cr, GtkWidget* widget, GdkRectangle* background_area, GdkRectangle* cell_area, GtkCellRendererState flags) {
	ClocksTitleRenderer * self;
	cairo_t* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	GdkRectangle _tmp2_ = {0};
	GdkRectangle _tmp3_ = {0};
	GtkCellRendererState _tmp4_ = 0;
	const gchar* _tmp5_ = NULL;
	GError * _inner_error_ = NULL;
	self = (ClocksTitleRenderer*) base;
	g_return_if_fail (cr != NULL);
	g_return_if_fail (widget != NULL);
	g_return_if_fail (background_area != NULL);
	g_return_if_fail (cell_area != NULL);
	_tmp0_ = cr;
	_tmp1_ = widget;
	_tmp2_ = *cell_area;
	_tmp3_ = *cell_area;
	_tmp4_ = flags;
	GTK_CELL_RENDERER_CLASS (clocks_title_renderer_parent_class)->render ((GtkCellRenderer*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_cell_renderer_text_get_type (), GtkCellRendererText), _tmp0_, _tmp1_, &_tmp2_, &_tmp3_, _tmp4_);
	_tmp5_ = self->priv->_title_icon;
	if (_tmp5_ != NULL) {
		GtkStyleContext* context = NULL;
		GtkWidget* _tmp6_ = NULL;
		GtkStyleContext* _tmp7_ = NULL;
		GtkStyleContext* _tmp8_ = NULL;
		GtkStyleContext* _tmp9_ = NULL;
		cairo_t* _tmp10_ = NULL;
		cairo_t* _tmp11_ = NULL;
		GdkRectangle _tmp12_ = {0};
		cairo_t* _tmp13_ = NULL;
		cairo_t* _tmp14_ = NULL;
		GdkRectangle _tmp15_ = {0};
		gint _tmp16_ = 0;
		GdkRectangle _tmp17_ = {0};
		gint _tmp18_ = 0;
		PangoLayout* layout = NULL;
		GtkWidget* _tmp19_ = NULL;
		PangoLayout* _tmp20_ = NULL;
		PangoLayout* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		PangoLayout* _tmp24_ = NULL;
		gint text_w = 0;
		gint text_h = 0;
		PangoLayout* _tmp25_ = NULL;
		gint _tmp26_ = 0;
		gint _tmp27_ = 0;
		gint x = 0;
		GdkRectangle _tmp28_ = {0};
		gint _tmp29_ = 0;
		gint _tmp30_ = 0;
		gint _tmp31_ = 0;
		gint y = 0;
		gint _tmp32_ = 0;
		GtkWidget* _tmp33_ = NULL;
		GtkTextDirection _tmp34_ = 0;
		GtkIconTheme* icon_theme = NULL;
		GdkScreen* _tmp40_ = NULL;
		GtkIconTheme* _tmp41_ = NULL;
		GtkIconTheme* _tmp42_ = NULL;
		GtkStyleContext* _tmp62_ = NULL;
		cairo_t* _tmp63_ = NULL;
		_tmp6_ = widget;
		_tmp7_ = gtk_widget_get_style_context (_tmp6_);
		_tmp8_ = _g_object_ref0 (_tmp7_);
		context = _tmp8_;
		_tmp9_ = context;
		gtk_style_context_save (_tmp9_);
		_tmp10_ = cr;
		cairo_save (_tmp10_);
		_tmp11_ = cr;
		_tmp12_ = *cell_area;
		gdk_cairo_rectangle (_tmp11_, &_tmp12_);
		_tmp13_ = cr;
		cairo_clip (_tmp13_);
		_tmp14_ = cr;
		_tmp15_ = *cell_area;
		_tmp16_ = _tmp15_.x;
		_tmp17_ = *cell_area;
		_tmp18_ = _tmp17_.y;
		cairo_translate (_tmp14_, (gdouble) _tmp16_, (gdouble) _tmp18_);
		_tmp19_ = widget;
		_tmp20_ = gtk_widget_create_pango_layout (_tmp19_, "");
		layout = _tmp20_;
		_tmp21_ = layout;
		_tmp22_ = clocks_title_renderer_get_title (self);
		_tmp23_ = _tmp22_;
		pango_layout_set_markup (_tmp21_, _tmp23_, -1);
		_tmp24_ = layout;
		pango_layout_set_alignment (_tmp24_, PANGO_ALIGN_CENTER);
		_tmp25_ = layout;
		pango_layout_get_pixel_size (_tmp25_, &_tmp26_, &_tmp27_);
		text_w = _tmp26_;
		text_h = _tmp27_;
		_tmp28_ = *cell_area;
		_tmp29_ = _tmp28_.width;
		_tmp30_ = text_w;
		_tmp31_ = self->priv->ICON_XOFF;
		x = ((_tmp29_ - _tmp30_) / 2) - _tmp31_;
		_tmp32_ = self->priv->ICON_YOFF;
		y = _tmp32_;
		_tmp33_ = widget;
		_tmp34_ = gtk_widget_get_direction (_tmp33_);
		if (_tmp34_ == GTK_TEXT_DIR_RTL) {
			GdkRectangle _tmp35_ = {0};
			gint _tmp36_ = 0;
			gint _tmp37_ = 0;
			gint _tmp38_ = 0;
			gint _tmp39_ = 0;
			_tmp35_ = *cell_area;
			_tmp36_ = _tmp35_.width;
			_tmp37_ = text_w;
			_tmp38_ = self->priv->ICON_XOFF;
			_tmp39_ = self->priv->ICON_SIZE;
			x = (((_tmp36_ + _tmp37_) / 2) + _tmp38_) - _tmp39_;
		}
		_tmp40_ = gdk_screen_get_default ();
		_tmp41_ = gtk_icon_theme_get_for_screen (_tmp40_);
		_tmp42_ = _g_object_ref0 (_tmp41_);
		icon_theme = _tmp42_;
		{
			GtkIconInfo* icon_info = NULL;
			GtkIconTheme* _tmp43_ = NULL;
			const gchar* _tmp44_ = NULL;
			gint _tmp45_ = 0;
			GtkWidget* _tmp46_ = NULL;
			gint _tmp47_ = 0;
			gint _tmp48_ = 0;
			GtkIconInfo* _tmp49_ = NULL;
			GtkIconInfo* _tmp50_ = NULL;
			cairo_surface_t* surface = NULL;
			GtkIconInfo* _tmp51_ = NULL;
			GtkWidget* _tmp52_ = NULL;
			GdkWindow* _tmp53_ = NULL;
			cairo_surface_t* _tmp54_ = NULL;
			GtkStyleContext* _tmp55_ = NULL;
			cairo_t* _tmp56_ = NULL;
			cairo_surface_t* _tmp57_ = NULL;
			gint _tmp58_ = 0;
			gint _tmp59_ = 0;
			_tmp43_ = icon_theme;
			_tmp44_ = self->priv->_title_icon;
			_tmp45_ = self->priv->ICON_SIZE;
			_tmp46_ = widget;
			_tmp47_ = gtk_widget_get_scale_factor (_tmp46_);
			_tmp48_ = _tmp47_;
			_tmp49_ = gtk_icon_theme_lookup_icon_for_scale (_tmp43_, _tmp44_, _tmp45_, _tmp48_, 0);
			icon_info = _tmp49_;
			_tmp50_ = icon_info;
			_vala_assert (_tmp50_ != NULL, "icon_info != null");
			_tmp51_ = icon_info;
			_tmp52_ = widget;
			_tmp53_ = gtk_widget_get_window (_tmp52_);
			_tmp54_ = gtk_icon_info_load_surface (_tmp51_, _tmp53_, &_inner_error_);
			surface = _tmp54_;
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				_gtk_icon_info_free0 (icon_info);
				goto __catch7_g_error;
			}
			_tmp55_ = context;
			_tmp56_ = cr;
			_tmp57_ = surface;
			_tmp58_ = x;
			_tmp59_ = y;
			gtk_render_icon_surface (_tmp55_, _tmp56_, _tmp57_, (gdouble) _tmp58_, (gdouble) _tmp59_);
			_cairo_surface_destroy0 (surface);
			_gtk_icon_info_free0 (icon_info);
		}
		goto __finally7;
		__catch7_g_error:
		{
			GError* e = NULL;
			GError* _tmp60_ = NULL;
			const gchar* _tmp61_ = NULL;
			e = _inner_error_;
			_inner_error_ = NULL;
			_tmp60_ = e;
			_tmp61_ = _tmp60_->message;
			g_warning ("widgets.vala:121: %s", _tmp61_);
			_g_error_free0 (e);
		}
		__finally7:
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			_g_object_unref0 (icon_theme);
			_g_object_unref0 (layout);
			_g_object_unref0 (context);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return;
		}
		_tmp62_ = context;
		gtk_style_context_restore (_tmp62_);
		_tmp63_ = cr;
		cairo_restore (_tmp63_);
		_g_object_unref0 (icon_theme);
		_g_object_unref0 (layout);
		_g_object_unref0 (context);
	}
}


const gchar* clocks_title_renderer_get_title (ClocksTitleRenderer* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_title;
	result = _tmp0_;
	return result;
}


void clocks_title_renderer_set_title (ClocksTitleRenderer* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_title);
	self->priv->_title = _tmp1_;
	_tmp2_ = self->priv->_title;
	g_object_set ((GtkCellRendererText*) self, "markup", _tmp2_, NULL);
	g_object_notify ((GObject *) self, "title");
}


const gchar* clocks_title_renderer_get_title_icon (ClocksTitleRenderer* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_title_icon;
	result = _tmp0_;
	return result;
}


void clocks_title_renderer_set_title_icon (ClocksTitleRenderer* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_title_icon);
	self->priv->_title_icon = _tmp1_;
	g_object_notify ((GObject *) self, "title-icon");
}


static void clocks_title_renderer_class_init (ClocksTitleRendererClass * klass) {
	clocks_title_renderer_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ClocksTitleRendererPrivate));
	((GtkCellRendererClass *) klass)->render = clocks_title_renderer_real_render;
	G_OBJECT_CLASS (klass)->get_property = _vala_clocks_title_renderer_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_clocks_title_renderer_set_property;
	G_OBJECT_CLASS (klass)->finalize = clocks_title_renderer_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_TITLE_RENDERER_TITLE, g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_TITLE_RENDERER_TITLE_ICON, g_param_spec_string ("title-icon", "title-icon", "title-icon", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void clocks_title_renderer_instance_init (ClocksTitleRenderer * self) {
	self->priv = CLOCKS_TITLE_RENDERER_GET_PRIVATE (self);
	self->priv->_title_icon = NULL;
}


static void clocks_title_renderer_finalize (GObject* obj) {
	ClocksTitleRenderer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CLOCKS_TYPE_TITLE_RENDERER, ClocksTitleRenderer);
	_g_free0 (self->priv->_title_icon);
	_g_free0 (self->priv->_title);
	G_OBJECT_CLASS (clocks_title_renderer_parent_class)->finalize (obj);
}


GType clocks_title_renderer_get_type (void) {
	static volatile gsize clocks_title_renderer_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_title_renderer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ClocksTitleRendererClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) clocks_title_renderer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ClocksTitleRenderer), 0, (GInstanceInitFunc) clocks_title_renderer_instance_init, NULL };
		GType clocks_title_renderer_type_id;
		clocks_title_renderer_type_id = g_type_register_static (gtk_cell_renderer_text_get_type (), "ClocksTitleRenderer", &g_define_type_info, 0);
		g_once_init_leave (&clocks_title_renderer_type_id__volatile, clocks_title_renderer_type_id);
	}
	return clocks_title_renderer_type_id__volatile;
}


static void _vala_clocks_title_renderer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ClocksTitleRenderer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_TITLE_RENDERER, ClocksTitleRenderer);
	switch (property_id) {
		case CLOCKS_TITLE_RENDERER_TITLE:
		g_value_set_string (value, clocks_title_renderer_get_title (self));
		break;
		case CLOCKS_TITLE_RENDERER_TITLE_ICON:
		g_value_set_string (value, clocks_title_renderer_get_title_icon (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_clocks_title_renderer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ClocksTitleRenderer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_TITLE_RENDERER, ClocksTitleRenderer);
	switch (property_id) {
		case CLOCKS_TITLE_RENDERER_TITLE:
		clocks_title_renderer_set_title (self, g_value_get_string (value));
		break;
		case CLOCKS_TITLE_RENDERER_TITLE_ICON:
		clocks_title_renderer_set_title_icon (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


ClocksDigitalClockRenderer* clocks_digital_clock_renderer_construct (GType object_type) {
	ClocksDigitalClockRenderer * self = NULL;
	self = (ClocksDigitalClockRenderer*) g_object_new (object_type, NULL);
	return self;
}


ClocksDigitalClockRenderer* clocks_digital_clock_renderer_new (void) {
	return clocks_digital_clock_renderer_construct (CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER);
}


static gpointer _pango_layout_line_ref0 (gpointer self) {
	return self ? pango_layout_line_ref (self) : NULL;
}


static void clocks_digital_clock_renderer_real_render (GtkCellRenderer* base, cairo_t* cr, GtkWidget* widget, GdkRectangle* background_area, GdkRectangle* cell_area, GtkCellRendererState flags) {
	ClocksDigitalClockRenderer * self;
	GtkStyleContext* context = NULL;
	GtkWidget* _tmp0_ = NULL;
	GtkStyleContext* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	GtkStyleContext* _tmp3_ = NULL;
	GtkStyleContext* _tmp4_ = NULL;
	GtkStyleContext* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	cairo_t* _tmp7_ = NULL;
	cairo_t* _tmp8_ = NULL;
	GdkRectangle _tmp9_ = {0};
	cairo_t* _tmp10_ = NULL;
	cairo_t* _tmp11_ = NULL;
	GdkRectangle _tmp12_ = {0};
	gint _tmp13_ = 0;
	GdkRectangle _tmp14_ = {0};
	gint _tmp15_ = 0;
	gint margin = 0;
	GdkRectangle _tmp16_ = {0};
	gint _tmp17_ = 0;
	gint _tmp18_ = 0;
	GdkPixbuf* _tmp19_ = NULL;
	GdkPixbuf* _tmp20_ = NULL;
	GdkPixbuf* _tmp21_ = NULL;
	gboolean _tmp22_ = FALSE;
	GtkStyleContext* _tmp35_ = NULL;
	cairo_t* _tmp36_ = NULL;
	gint _tmp37_ = 0;
	gint _tmp38_ = 0;
	GtkBorder border = {0};
	GtkStyleContext* _tmp39_ = NULL;
	GtkStyleContext* _tmp40_ = NULL;
	GtkStateFlags _tmp41_ = 0;
	GtkBorder _tmp42_ = {0};
	gint w = 0;
	GdkRectangle _tmp43_ = {0};
	gint _tmp44_ = 0;
	gint _tmp45_ = 0;
	GtkBorder _tmp46_ = {0};
	gint16 _tmp47_ = 0;
	GtkBorder _tmp48_ = {0};
	gint16 _tmp49_ = 0;
	PangoLayout* layout = NULL;
	GtkWidget* _tmp50_ = NULL;
	PangoLayout* _tmp51_ = NULL;
	PangoLayout* _tmp52_ = NULL;
	const gchar* _tmp53_ = NULL;
	gchar* _tmp54_ = NULL;
	gchar* _tmp55_ = NULL;
	PangoLayout* _tmp56_ = NULL;
	gint _tmp57_ = 0;
	PangoLayout* _tmp58_ = NULL;
	gint text_w = 0;
	gint text_h = 0;
	PangoLayout* _tmp59_ = NULL;
	gint _tmp60_ = 0;
	gint _tmp61_ = 0;
	PangoLayout* layout_subtext = NULL;
	gint subtext_w = 0;
	gint subtext_h = 0;
	gint subtext_pad = 0;
	const gchar* _tmp62_ = NULL;
	gint stripe_h = 0;
	gint x = 0;
	gint _tmp83_ = 0;
	GtkBorder _tmp84_ = {0};
	gint16 _tmp85_ = 0;
	gint y = 0;
	GdkRectangle _tmp86_ = {0};
	gint _tmp87_ = 0;
	gint _tmp88_ = 0;
	GtkStyleContext* _tmp89_ = NULL;
	GtkStyleContext* _tmp90_ = NULL;
	cairo_t* _tmp91_ = NULL;
	gint _tmp92_ = 0;
	gint _tmp93_ = 0;
	gint _tmp94_ = 0;
	gint _tmp95_ = 0;
	GtkStyleContext* _tmp96_ = NULL;
	cairo_t* _tmp97_ = NULL;
	gint _tmp98_ = 0;
	gint _tmp99_ = 0;
	gint _tmp100_ = 0;
	gint _tmp101_ = 0;
	gint _tmp102_ = 0;
	gint _tmp103_ = 0;
	gint _tmp104_ = 0;
	gint _tmp105_ = 0;
	gint _tmp106_ = 0;
	GtkStyleContext* _tmp107_ = NULL;
	cairo_t* _tmp108_ = NULL;
	gint _tmp109_ = 0;
	gint _tmp110_ = 0;
	PangoLayout* _tmp111_ = NULL;
	const gchar* _tmp112_ = NULL;
	GtkStyleContext* _tmp121_ = NULL;
	gboolean _tmp122_ = FALSE;
	gboolean _tmp123_ = FALSE;
	cairo_t* _tmp157_ = NULL;
	self = (ClocksDigitalClockRenderer*) base;
	g_return_if_fail (cr != NULL);
	g_return_if_fail (widget != NULL);
	g_return_if_fail (background_area != NULL);
	g_return_if_fail (cell_area != NULL);
	_tmp0_ = widget;
	_tmp1_ = gtk_widget_get_style_context (_tmp0_);
	_tmp2_ = _g_object_ref0 (_tmp1_);
	context = _tmp2_;
	_tmp3_ = context;
	gtk_style_context_save (_tmp3_);
	_tmp4_ = context;
	gtk_style_context_add_class (_tmp4_, "clocks-digital-renderer");
	_tmp5_ = context;
	_tmp6_ = self->priv->_css_class;
	gtk_style_context_add_class (_tmp5_, _tmp6_);
	_tmp7_ = cr;
	cairo_save (_tmp7_);
	_tmp8_ = cr;
	_tmp9_ = *cell_area;
	gdk_cairo_rectangle (_tmp8_, &_tmp9_);
	_tmp10_ = cr;
	cairo_clip (_tmp10_);
	_tmp11_ = cr;
	_tmp12_ = *cell_area;
	_tmp13_ = _tmp12_.x;
	_tmp14_ = *cell_area;
	_tmp15_ = _tmp14_.y;
	cairo_translate (_tmp11_, (gdouble) _tmp13_, (gdouble) _tmp15_);
	_tmp16_ = *cell_area;
	_tmp17_ = _tmp16_.width;
	_tmp18_ = MAX (CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_MARGIN, (gint) ((_tmp17_ - CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_SIZE) / 2));
	margin = _tmp18_;
	g_object_get ((GtkCellRendererPixbuf*) self, "pixbuf", &_tmp19_, NULL);
	_tmp20_ = _tmp19_;
	_tmp21_ = _tmp20_;
	_tmp22_ = _tmp21_ != NULL;
	_g_object_unref0 (_tmp21_);
	if (_tmp22_) {
		GdkRectangle area = {0};
		gint _tmp23_ = 0;
		gint _tmp24_ = 0;
		GdkRectangle _tmp25_ = {0};
		cairo_t* _tmp26_ = NULL;
		GtkWidget* _tmp27_ = NULL;
		GdkRectangle _tmp28_ = {0};
		GdkRectangle _tmp29_ = {0};
		GtkCellRendererState _tmp30_ = 0;
		_tmp23_ = margin;
		_tmp24_ = margin;
		_tmp25_.x = _tmp23_;
		_tmp25_.y = _tmp24_;
		_tmp25_.width = CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_SIZE;
		_tmp25_.height = CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_SIZE;
		area = _tmp25_;
		_tmp26_ = cr;
		_tmp27_ = widget;
		_tmp28_ = area;
		_tmp29_ = area;
		_tmp30_ = flags;
		GTK_CELL_RENDERER_CLASS (clocks_digital_clock_renderer_parent_class)->render ((GtkCellRenderer*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_cell_renderer_pixbuf_get_type (), GtkCellRendererPixbuf), _tmp26_, _tmp27_, &_tmp28_, &_tmp29_, _tmp30_);
	} else {
		GtkStyleContext* _tmp31_ = NULL;
		cairo_t* _tmp32_ = NULL;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		_tmp31_ = context;
		_tmp32_ = cr;
		_tmp33_ = margin;
		_tmp34_ = margin;
		gtk_render_background (_tmp31_, _tmp32_, (gdouble) _tmp33_, (gdouble) _tmp34_, (gdouble) CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_SIZE, (gdouble) CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_SIZE);
	}
	_tmp35_ = context;
	_tmp36_ = cr;
	_tmp37_ = margin;
	_tmp38_ = margin;
	gtk_render_frame (_tmp35_, _tmp36_, (gdouble) _tmp37_, (gdouble) _tmp38_, (gdouble) CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_SIZE, (gdouble) CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_SIZE);
	_tmp39_ = context;
	_tmp40_ = context;
	_tmp41_ = gtk_style_context_get_state (_tmp40_);
	gtk_style_context_get_border (_tmp39_, _tmp41_, &_tmp42_);
	border = _tmp42_;
	_tmp43_ = *cell_area;
	_tmp44_ = _tmp43_.width;
	_tmp45_ = margin;
	_tmp46_ = border;
	_tmp47_ = _tmp46_.left;
	_tmp48_ = border;
	_tmp49_ = _tmp48_.right;
	w = ((_tmp44_ - (2 * _tmp45_)) - _tmp47_) - _tmp49_;
	_tmp50_ = widget;
	_tmp51_ = gtk_widget_create_pango_layout (_tmp50_, "");
	layout = _tmp51_;
	_tmp52_ = layout;
	_tmp53_ = self->priv->_text;
	_tmp54_ = g_strdup_printf ("<span font_desc=\"32.0\">%s</span>", _tmp53_);
	_tmp55_ = _tmp54_;
	pango_layout_set_markup (_tmp52_, _tmp55_, -1);
	_g_free0 (_tmp55_);
	_tmp56_ = layout;
	_tmp57_ = w;
	pango_layout_set_width (_tmp56_, _tmp57_ * PANGO_SCALE);
	_tmp58_ = layout;
	pango_layout_set_alignment (_tmp58_, PANGO_ALIGN_CENTER);
	_tmp59_ = layout;
	pango_layout_get_pixel_size (_tmp59_, &_tmp60_, &_tmp61_);
	text_w = _tmp60_;
	text_h = _tmp61_;
	layout_subtext = NULL;
	subtext_w = 0;
	subtext_h = 0;
	subtext_pad = 0;
	_tmp62_ = self->priv->_subtext;
	if (_tmp62_ != NULL) {
		GtkWidget* _tmp63_ = NULL;
		PangoLayout* _tmp64_ = NULL;
		PangoLayout* _tmp65_ = NULL;
		const gchar* _tmp66_ = NULL;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
		PangoLayout* _tmp69_ = NULL;
		gint _tmp70_ = 0;
		PangoLayout* _tmp71_ = NULL;
		PangoLayout* _tmp72_ = NULL;
		gint _tmp73_ = 0;
		gint _tmp74_ = 0;
		PangoLayoutLine* line = NULL;
		PangoLayout* _tmp75_ = NULL;
		PangoLayoutLine* _tmp76_ = NULL;
		PangoLayoutLine* _tmp77_ = NULL;
		PangoRectangle ink_rect = {0};
		PangoRectangle log_rect = {0};
		PangoLayoutLine* _tmp78_ = NULL;
		PangoRectangle _tmp79_ = {0};
		PangoRectangle _tmp80_ = {0};
		PangoRectangle _tmp81_ = {0};
		gint _tmp82_ = 0;
		_tmp63_ = widget;
		_tmp64_ = gtk_widget_create_pango_layout (_tmp63_, "");
		_g_object_unref0 (layout_subtext);
		layout_subtext = _tmp64_;
		_tmp65_ = layout_subtext;
		_tmp66_ = self->priv->_subtext;
		_tmp67_ = g_strdup_printf ("<span font_desc=\"14.0\">%s</span>", _tmp66_);
		_tmp68_ = _tmp67_;
		pango_layout_set_markup (_tmp65_, _tmp68_, -1);
		_g_free0 (_tmp68_);
		_tmp69_ = layout_subtext;
		_tmp70_ = w;
		pango_layout_set_width (_tmp69_, _tmp70_ * PANGO_SCALE);
		_tmp71_ = layout_subtext;
		pango_layout_set_alignment (_tmp71_, PANGO_ALIGN_CENTER);
		_tmp72_ = layout_subtext;
		pango_layout_get_pixel_size (_tmp72_, &_tmp73_, &_tmp74_);
		subtext_w = _tmp73_;
		subtext_h = _tmp74_;
		subtext_pad = 4;
		_tmp75_ = layout_subtext;
		_tmp76_ = pango_layout_get_line (_tmp75_, 0);
		_tmp77_ = _pango_layout_line_ref0 (_tmp76_);
		line = _tmp77_;
		_tmp78_ = line;
		pango_layout_line_get_pixel_extents (_tmp78_, &_tmp79_, &_tmp80_);
		ink_rect = _tmp79_;
		log_rect = _tmp80_;
		_tmp81_ = log_rect;
		_tmp82_ = _tmp81_.width;
		subtext_w = _tmp82_;
		_pango_layout_line_unref0 (line);
	}
	stripe_h = 128;
	_tmp83_ = margin;
	_tmp84_ = border;
	_tmp85_ = _tmp84_.left;
	x = _tmp83_ + _tmp85_;
	_tmp86_ = *cell_area;
	_tmp87_ = _tmp86_.height;
	_tmp88_ = stripe_h;
	y = (_tmp87_ - _tmp88_) / 2;
	_tmp89_ = context;
	gtk_style_context_add_class (_tmp89_, "stripe");
	_tmp90_ = context;
	_tmp91_ = cr;
	_tmp92_ = x;
	_tmp93_ = y;
	_tmp94_ = w;
	_tmp95_ = stripe_h;
	gtk_render_frame (_tmp90_, _tmp91_, (gdouble) _tmp92_, (gdouble) _tmp93_, (gdouble) _tmp94_, (gdouble) _tmp95_);
	_tmp96_ = context;
	_tmp97_ = cr;
	_tmp98_ = x;
	_tmp99_ = y;
	_tmp100_ = w;
	_tmp101_ = stripe_h;
	gtk_render_background (_tmp96_, _tmp97_, (gdouble) _tmp98_, (gdouble) _tmp99_, (gdouble) _tmp100_, (gdouble) _tmp101_);
	_tmp102_ = y;
	_tmp103_ = stripe_h;
	_tmp104_ = text_h;
	_tmp105_ = subtext_h;
	_tmp106_ = subtext_pad;
	y = _tmp102_ + ((((_tmp103_ - _tmp104_) - _tmp105_) - _tmp106_) / 2);
	_tmp107_ = context;
	_tmp108_ = cr;
	_tmp109_ = x;
	_tmp110_ = y;
	_tmp111_ = layout;
	gtk_render_layout (_tmp107_, _tmp108_, (gdouble) _tmp109_, (gdouble) _tmp110_, _tmp111_);
	_tmp112_ = self->priv->_subtext;
	if (_tmp112_ != NULL) {
		gint _tmp113_ = 0;
		gint _tmp114_ = 0;
		gint _tmp115_ = 0;
		GtkStyleContext* _tmp116_ = NULL;
		cairo_t* _tmp117_ = NULL;
		gint _tmp118_ = 0;
		gint _tmp119_ = 0;
		PangoLayout* _tmp120_ = NULL;
		_tmp113_ = y;
		_tmp114_ = text_h;
		_tmp115_ = subtext_pad;
		y = _tmp113_ + (_tmp114_ + _tmp115_);
		_tmp116_ = context;
		_tmp117_ = cr;
		_tmp118_ = x;
		_tmp119_ = y;
		_tmp120_ = layout_subtext;
		gtk_render_layout (_tmp116_, _tmp117_, (gdouble) _tmp118_, (gdouble) _tmp119_, _tmp120_);
	}
	_tmp121_ = context;
	gtk_style_context_restore (_tmp121_);
	_tmp123_ = self->priv->_selectable;
	if (_tmp123_) {
		gboolean _tmp124_ = FALSE;
		_tmp124_ = self->priv->_toggle_visible;
		_tmp122_ = _tmp124_;
	} else {
		_tmp122_ = FALSE;
	}
	if (_tmp122_) {
		gint xpad = 0;
		gint ypad = 0;
		gint x_offset = 0;
		gint _tmp125_ = 0;
		gint _tmp126_ = 0;
		GtkWidget* _tmp127_ = NULL;
		GtkTextDirection _tmp128_ = 0;
		gint check_x = 0;
		gint _tmp133_ = 0;
		gint check_y = 0;
		GdkRectangle _tmp134_ = {0};
		gint _tmp135_ = 0;
		gint _tmp136_ = 0;
		GtkStyleContext* _tmp137_ = NULL;
		GtkStyleContext* _tmp138_ = NULL;
		GtkStyleContext* _tmp139_ = NULL;
		GtkStyleContext* _tmp140_ = NULL;
		const gchar* _tmp141_ = NULL;
		gboolean _tmp142_ = FALSE;
		GtkStyleContext* _tmp144_ = NULL;
		cairo_t* _tmp145_ = NULL;
		gint _tmp146_ = 0;
		gint _tmp147_ = 0;
		GtkStyleContext* _tmp148_ = NULL;
		cairo_t* _tmp149_ = NULL;
		gint _tmp150_ = 0;
		gint _tmp151_ = 0;
		GtkStyleContext* _tmp152_ = NULL;
		cairo_t* _tmp153_ = NULL;
		gint _tmp154_ = 0;
		gint _tmp155_ = 0;
		GtkStyleContext* _tmp156_ = NULL;
		gtk_cell_renderer_get_padding ((GtkCellRenderer*) self, &_tmp125_, &_tmp126_);
		xpad = _tmp125_;
		ypad = _tmp126_;
		_tmp127_ = widget;
		_tmp128_ = gtk_widget_get_direction (_tmp127_);
		if (_tmp128_ == GTK_TEXT_DIR_RTL) {
			gint _tmp129_ = 0;
			_tmp129_ = xpad;
			x_offset = _tmp129_;
		} else {
			GdkRectangle _tmp130_ = {0};
			gint _tmp131_ = 0;
			gint _tmp132_ = 0;
			_tmp130_ = *cell_area;
			_tmp131_ = _tmp130_.width;
			_tmp132_ = xpad;
			x_offset = (_tmp131_ - CLOCKS_DIGITAL_CLOCK_RENDERER_CHECK_ICON_SIZE) - _tmp132_;
		}
		_tmp133_ = x_offset;
		check_x = _tmp133_;
		_tmp134_ = *cell_area;
		_tmp135_ = _tmp134_.height;
		_tmp136_ = ypad;
		check_y = (_tmp135_ - CLOCKS_DIGITAL_CLOCK_RENDERER_CHECK_ICON_SIZE) - _tmp136_;
		_tmp137_ = context;
		gtk_style_context_save (_tmp137_);
		_tmp138_ = context;
		gtk_style_context_add_class (_tmp138_, GTK_STYLE_CLASS_CHECK);
		_tmp139_ = context;
		gtk_style_context_add_class (_tmp139_, "clocks-digital-renderer-check");
		_tmp140_ = context;
		_tmp141_ = self->priv->_css_class;
		gtk_style_context_add_class (_tmp140_, _tmp141_);
		_tmp142_ = self->priv->_checked;
		if (_tmp142_) {
			GtkStyleContext* _tmp143_ = NULL;
			_tmp143_ = context;
			gtk_style_context_set_state (_tmp143_, GTK_STATE_FLAG_CHECKED);
		}
		_tmp144_ = context;
		_tmp145_ = cr;
		_tmp146_ = check_x;
		_tmp147_ = check_y;
		gtk_render_background (_tmp144_, _tmp145_, (gdouble) _tmp146_, (gdouble) _tmp147_, (gdouble) CLOCKS_DIGITAL_CLOCK_RENDERER_CHECK_ICON_SIZE, (gdouble) CLOCKS_DIGITAL_CLOCK_RENDERER_CHECK_ICON_SIZE);
		_tmp148_ = context;
		_tmp149_ = cr;
		_tmp150_ = check_x;
		_tmp151_ = check_y;
		gtk_render_frame (_tmp148_, _tmp149_, (gdouble) _tmp150_, (gdouble) _tmp151_, (gdouble) CLOCKS_DIGITAL_CLOCK_RENDERER_CHECK_ICON_SIZE, (gdouble) CLOCKS_DIGITAL_CLOCK_RENDERER_CHECK_ICON_SIZE);
		_tmp152_ = context;
		_tmp153_ = cr;
		_tmp154_ = check_x;
		_tmp155_ = check_y;
		gtk_render_check (_tmp152_, _tmp153_, (gdouble) _tmp154_, (gdouble) _tmp155_, (gdouble) CLOCKS_DIGITAL_CLOCK_RENDERER_CHECK_ICON_SIZE, (gdouble) CLOCKS_DIGITAL_CLOCK_RENDERER_CHECK_ICON_SIZE);
		_tmp156_ = context;
		gtk_style_context_restore (_tmp156_);
	}
	_tmp157_ = cr;
	cairo_restore (_tmp157_);
	_g_object_unref0 (layout_subtext);
	_g_object_unref0 (layout);
	_g_object_unref0 (context);
}


const gchar* clocks_digital_clock_renderer_get_text (ClocksDigitalClockRenderer* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_text;
	result = _tmp0_;
	return result;
}


void clocks_digital_clock_renderer_set_text (ClocksDigitalClockRenderer* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_text);
	self->priv->_text = _tmp1_;
	g_object_notify ((GObject *) self, "text");
}


const gchar* clocks_digital_clock_renderer_get_subtext (ClocksDigitalClockRenderer* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_subtext;
	result = _tmp0_;
	return result;
}


void clocks_digital_clock_renderer_set_subtext (ClocksDigitalClockRenderer* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_subtext);
	self->priv->_subtext = _tmp1_;
	g_object_notify ((GObject *) self, "subtext");
}


const gchar* clocks_digital_clock_renderer_get_css_class (ClocksDigitalClockRenderer* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_css_class;
	result = _tmp0_;
	return result;
}


void clocks_digital_clock_renderer_set_css_class (ClocksDigitalClockRenderer* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_css_class);
	self->priv->_css_class = _tmp1_;
	g_object_notify ((GObject *) self, "css-class");
}


gboolean clocks_digital_clock_renderer_get_checked (ClocksDigitalClockRenderer* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->_checked;
	result = _tmp0_;
	return result;
}


void clocks_digital_clock_renderer_set_checked (ClocksDigitalClockRenderer* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->priv->_checked = _tmp0_;
	g_object_notify ((GObject *) self, "checked");
}


gboolean clocks_digital_clock_renderer_get_toggle_visible (ClocksDigitalClockRenderer* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->_toggle_visible;
	result = _tmp0_;
	return result;
}


void clocks_digital_clock_renderer_set_toggle_visible (ClocksDigitalClockRenderer* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->priv->_toggle_visible = _tmp0_;
	g_object_notify ((GObject *) self, "toggle-visible");
}


gboolean clocks_digital_clock_renderer_get_selectable (ClocksDigitalClockRenderer* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->_selectable;
	result = _tmp0_;
	return result;
}


void clocks_digital_clock_renderer_set_selectable (ClocksDigitalClockRenderer* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->priv->_selectable = _tmp0_;
	g_object_notify ((GObject *) self, "selectable");
}


static void clocks_digital_clock_renderer_class_init (ClocksDigitalClockRendererClass * klass) {
	clocks_digital_clock_renderer_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ClocksDigitalClockRendererPrivate));
	((GtkCellRendererClass *) klass)->render = clocks_digital_clock_renderer_real_render;
	G_OBJECT_CLASS (klass)->get_property = _vala_clocks_digital_clock_renderer_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_clocks_digital_clock_renderer_set_property;
	G_OBJECT_CLASS (klass)->finalize = clocks_digital_clock_renderer_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_DIGITAL_CLOCK_RENDERER_TEXT, g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_DIGITAL_CLOCK_RENDERER_SUBTEXT, g_param_spec_string ("subtext", "subtext", "subtext", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_DIGITAL_CLOCK_RENDERER_CSS_CLASS, g_param_spec_string ("css-class", "css-class", "css-class", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_DIGITAL_CLOCK_RENDERER_CHECKED, g_param_spec_boolean ("checked", "checked", "checked", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_DIGITAL_CLOCK_RENDERER_TOGGLE_VISIBLE, g_param_spec_boolean ("toggle-visible", "toggle-visible", "toggle-visible", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_DIGITAL_CLOCK_RENDERER_SELECTABLE, g_param_spec_boolean ("selectable", "selectable", "selectable", TRUE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void clocks_digital_clock_renderer_instance_init (ClocksDigitalClockRenderer * self) {
	self->priv = CLOCKS_DIGITAL_CLOCK_RENDERER_GET_PRIVATE (self);
	self->priv->_checked = FALSE;
	self->priv->_toggle_visible = FALSE;
	self->priv->_selectable = TRUE;
}


static void clocks_digital_clock_renderer_finalize (GObject* obj) {
	ClocksDigitalClockRenderer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER, ClocksDigitalClockRenderer);
	_g_free0 (self->priv->_text);
	_g_free0 (self->priv->_subtext);
	_g_free0 (self->priv->_css_class);
	G_OBJECT_CLASS (clocks_digital_clock_renderer_parent_class)->finalize (obj);
}


GType clocks_digital_clock_renderer_get_type (void) {
	static volatile gsize clocks_digital_clock_renderer_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_digital_clock_renderer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ClocksDigitalClockRendererClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) clocks_digital_clock_renderer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ClocksDigitalClockRenderer), 0, (GInstanceInitFunc) clocks_digital_clock_renderer_instance_init, NULL };
		GType clocks_digital_clock_renderer_type_id;
		clocks_digital_clock_renderer_type_id = g_type_register_static (gtk_cell_renderer_pixbuf_get_type (), "ClocksDigitalClockRenderer", &g_define_type_info, 0);
		g_once_init_leave (&clocks_digital_clock_renderer_type_id__volatile, clocks_digital_clock_renderer_type_id);
	}
	return clocks_digital_clock_renderer_type_id__volatile;
}


static void _vala_clocks_digital_clock_renderer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ClocksDigitalClockRenderer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER, ClocksDigitalClockRenderer);
	switch (property_id) {
		case CLOCKS_DIGITAL_CLOCK_RENDERER_TEXT:
		g_value_set_string (value, clocks_digital_clock_renderer_get_text (self));
		break;
		case CLOCKS_DIGITAL_CLOCK_RENDERER_SUBTEXT:
		g_value_set_string (value, clocks_digital_clock_renderer_get_subtext (self));
		break;
		case CLOCKS_DIGITAL_CLOCK_RENDERER_CSS_CLASS:
		g_value_set_string (value, clocks_digital_clock_renderer_get_css_class (self));
		break;
		case CLOCKS_DIGITAL_CLOCK_RENDERER_CHECKED:
		g_value_set_boolean (value, clocks_digital_clock_renderer_get_checked (self));
		break;
		case CLOCKS_DIGITAL_CLOCK_RENDERER_TOGGLE_VISIBLE:
		g_value_set_boolean (value, clocks_digital_clock_renderer_get_toggle_visible (self));
		break;
		case CLOCKS_DIGITAL_CLOCK_RENDERER_SELECTABLE:
		g_value_set_boolean (value, clocks_digital_clock_renderer_get_selectable (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_clocks_digital_clock_renderer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ClocksDigitalClockRenderer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER, ClocksDigitalClockRenderer);
	switch (property_id) {
		case CLOCKS_DIGITAL_CLOCK_RENDERER_TEXT:
		clocks_digital_clock_renderer_set_text (self, g_value_get_string (value));
		break;
		case CLOCKS_DIGITAL_CLOCK_RENDERER_SUBTEXT:
		clocks_digital_clock_renderer_set_subtext (self, g_value_get_string (value));
		break;
		case CLOCKS_DIGITAL_CLOCK_RENDERER_CSS_CLASS:
		clocks_digital_clock_renderer_set_css_class (self, g_value_get_string (value));
		break;
		case CLOCKS_DIGITAL_CLOCK_RENDERER_CHECKED:
		clocks_digital_clock_renderer_set_checked (self, g_value_get_boolean (value));
		break;
		case CLOCKS_DIGITAL_CLOCK_RENDERER_TOGGLE_VISIBLE:
		clocks_digital_clock_renderer_set_toggle_visible (self, g_value_get_boolean (value));
		break;
		case CLOCKS_DIGITAL_CLOCK_RENDERER_SELECTABLE:
		clocks_digital_clock_renderer_set_selectable (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


void clocks_content_item_get_thumb_properties (ClocksContentItem* self, gchar** text, gchar** subtext, GdkPixbuf** pixbuf, gchar** css_class) {
	g_return_if_fail (self != NULL);
	CLOCKS_CONTENT_ITEM_GET_INTERFACE (self)->get_thumb_properties (self, text, subtext, pixbuf, css_class);
}


void clocks_content_item_serialize (ClocksContentItem* self, GVariantBuilder* builder) {
	g_return_if_fail (self != NULL);
	CLOCKS_CONTENT_ITEM_GET_INTERFACE (self)->serialize (self, builder);
}


const gchar* clocks_content_item_get_name (ClocksContentItem* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return CLOCKS_CONTENT_ITEM_GET_INTERFACE (self)->get_name (self);
}


void clocks_content_item_set_name (ClocksContentItem* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	CLOCKS_CONTENT_ITEM_GET_INTERFACE (self)->set_name (self, value);
}


const gchar* clocks_content_item_get_title_icon (ClocksContentItem* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return CLOCKS_CONTENT_ITEM_GET_INTERFACE (self)->get_title_icon (self);
}


void clocks_content_item_set_title_icon (ClocksContentItem* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	CLOCKS_CONTENT_ITEM_GET_INTERFACE (self)->set_title_icon (self, value);
}


gboolean clocks_content_item_get_selectable (ClocksContentItem* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return CLOCKS_CONTENT_ITEM_GET_INTERFACE (self)->get_selectable (self);
}


void clocks_content_item_set_selectable (ClocksContentItem* self, gboolean value) {
	g_return_if_fail (self != NULL);
	CLOCKS_CONTENT_ITEM_GET_INTERFACE (self)->set_selectable (self, value);
}


gboolean clocks_content_item_get_selected (ClocksContentItem* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return CLOCKS_CONTENT_ITEM_GET_INTERFACE (self)->get_selected (self);
}


void clocks_content_item_set_selected (ClocksContentItem* self, gboolean value) {
	g_return_if_fail (self != NULL);
	CLOCKS_CONTENT_ITEM_GET_INTERFACE (self)->set_selected (self, value);
}


static void clocks_content_item_base_init (ClocksContentItemIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("title-icon", "title-icon", "title-icon", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_boolean ("selectable", "selectable", "selectable", TRUE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_boolean ("selected", "selected", "selected", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


GType clocks_content_item_get_type (void) {
	static volatile gsize clocks_content_item_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_content_item_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ClocksContentItemIface), (GBaseInitFunc) clocks_content_item_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType clocks_content_item_type_id;
		clocks_content_item_type_id = g_type_register_static (G_TYPE_INTERFACE, "ClocksContentItem", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (clocks_content_item_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&clocks_content_item_type_id__volatile, clocks_content_item_type_id);
	}
	return clocks_content_item_type_id__volatile;
}


static void __lambda10_ (ClocksContentStore* self, guint position, guint removed, guint added) {
	guint _tmp0_ = 0U;
	guint _tmp1_ = 0U;
	guint _tmp2_ = 0U;
	_tmp0_ = position;
	_tmp1_ = removed;
	_tmp2_ = added;
	g_list_model_items_changed ((GListModel*) self, _tmp0_, _tmp1_, _tmp2_);
}


static void ___lambda10__g_list_model_items_changed (GListModel* _sender, guint position, guint removed, guint added, gpointer self) {
	__lambda10_ ((ClocksContentStore*) self, position, removed, added);
}


ClocksContentStore* clocks_content_store_construct (GType object_type) {
	ClocksContentStore * self = NULL;
	GListStore* _tmp0_ = NULL;
	GListStore* _tmp1_ = NULL;
	self = (ClocksContentStore*) g_object_new (object_type, NULL);
	_tmp0_ = g_list_store_new (CLOCKS_TYPE_CONTENT_ITEM);
	_g_object_unref0 (self->priv->store);
	self->priv->store = _tmp0_;
	_tmp1_ = self->priv->store;
	g_signal_connect_object ((GListModel*) _tmp1_, "items-changed", (GCallback) ___lambda10__g_list_model_items_changed, self, 0);
	return self;
}


ClocksContentStore* clocks_content_store_new (void) {
	return clocks_content_store_construct (CLOCKS_TYPE_CONTENT_STORE);
}


static GType clocks_content_store_real_get_item_type (GListModel* base) {
	ClocksContentStore * self;
	GType result = 0UL;
	GListStore* _tmp0_ = NULL;
	GType _tmp1_ = 0UL;
	self = (ClocksContentStore*) base;
	_tmp0_ = self->priv->store;
	_tmp1_ = g_list_model_get_item_type ((GListModel*) _tmp0_);
	result = _tmp1_;
	return result;
}


static guint clocks_content_store_real_get_n_items (GListModel* base) {
	ClocksContentStore * self;
	guint result = 0U;
	GListStore* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	self = (ClocksContentStore*) base;
	_tmp0_ = self->priv->store;
	_tmp1_ = g_list_model_get_n_items ((GListModel*) _tmp0_);
	result = _tmp1_;
	return result;
}


static GObject* clocks_content_store_real_get_item (GListModel* base, guint position) {
	ClocksContentStore * self;
	GObject* result = NULL;
	GListStore* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	GObject* _tmp2_ = NULL;
	self = (ClocksContentStore*) base;
	_tmp0_ = self->priv->store;
	_tmp1_ = position;
	_tmp2_ = g_list_model_get_item ((GListModel*) _tmp0_, _tmp1_);
	result = _tmp2_;
	return result;
}


void clocks_content_store_set_sorting (ClocksContentStore* self, GCompareDataFunc sort, void* sort_target, GDestroyNotify sort_target_destroy_notify) {
	GCompareDataFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	GDestroyNotify _tmp0__target_destroy_notify = NULL;
	GListStore* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
	g_return_if_fail (self != NULL);
	_tmp0_ = sort;
	_tmp0__target = sort_target;
	_tmp0__target_destroy_notify = sort_target_destroy_notify;
	sort_target_destroy_notify = NULL;
	(self->priv->sort_func_target_destroy_notify == NULL) ? NULL : (self->priv->sort_func_target_destroy_notify (self->priv->sort_func_target), NULL);
	self->priv->sort_func = NULL;
	self->priv->sort_func_target = NULL;
	self->priv->sort_func_target_destroy_notify = NULL;
	self->priv->sort_func = _tmp0_;
	self->priv->sort_func_target = _tmp0__target;
	self->priv->sort_func_target_destroy_notify = _tmp0__target_destroy_notify;
	_tmp1_ = self->priv->store;
	_tmp2_ = g_list_model_get_n_items ((GListModel*) _tmp1_);
	_vala_assert (_tmp2_ == ((guint) 0), "store.get_n_items () == 0");
	(sort_target_destroy_notify == NULL) ? NULL : (sort_target_destroy_notify (sort_target), NULL);
	sort = NULL;
	sort_target = NULL;
	sort_target_destroy_notify = NULL;
}


static void clocks_content_store_on_item_selection_toggle (ClocksContentStore* self, GObject* o, GParamSpec* p) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (o != NULL);
	g_return_if_fail (p != NULL);
	g_signal_emit_by_name (self, "selection-changed");
}


static void _clocks_content_store_on_item_selection_toggle_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
	clocks_content_store_on_item_selection_toggle ((ClocksContentStore*) self, _sender, pspec);
}


void clocks_content_store_add (ClocksContentStore* self, ClocksContentItem* item) {
	GCompareDataFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	ClocksContentItem* _tmp6_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (item != NULL);
	_tmp0_ = self->priv->sort_func;
	_tmp0__target = self->priv->sort_func_target;
	if (_tmp0_ == NULL) {
		GListStore* _tmp1_ = NULL;
		ClocksContentItem* _tmp2_ = NULL;
		_tmp1_ = self->priv->store;
		_tmp2_ = item;
		g_list_store_append (_tmp1_, (GObject*) _tmp2_);
	} else {
		GListStore* _tmp3_ = NULL;
		ClocksContentItem* _tmp4_ = NULL;
		GCompareDataFunc _tmp5_ = NULL;
		void* _tmp5__target = NULL;
		_tmp3_ = self->priv->store;
		_tmp4_ = item;
		_tmp5_ = self->priv->sort_func;
		_tmp5__target = self->priv->sort_func_target;
		g_list_store_insert_sorted (_tmp3_, (GObject*) _tmp4_, _tmp5_, _tmp5__target);
	}
	_tmp6_ = item;
	g_signal_connect_object ((GObject*) _tmp6_, "notify::selected", (GCallback) _clocks_content_store_on_item_selection_toggle_g_object_notify, self, 0);
}


void clocks_content_store_foreach (ClocksContentStore* self, ClocksContentStoreForeachFunc func, void* func_target) {
	guint n = 0U;
	GListStore* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->store;
	_tmp1_ = g_list_model_get_n_items ((GListModel*) _tmp0_);
	n = _tmp1_;
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp2_ = FALSE;
			_tmp2_ = TRUE;
			while (TRUE) {
				gint _tmp4_ = 0;
				guint _tmp5_ = 0U;
				ClocksContentStoreForeachFunc _tmp6_ = NULL;
				void* _tmp6__target = NULL;
				GListStore* _tmp7_ = NULL;
				gint _tmp8_ = 0;
				GObject* _tmp9_ = NULL;
				ClocksContentItem* _tmp10_ = NULL;
				ClocksContentItem* _tmp11_ = NULL;
				if (!_tmp2_) {
					gint _tmp3_ = 0;
					_tmp3_ = i;
					i = _tmp3_ + 1;
				}
				_tmp2_ = FALSE;
				_tmp4_ = i;
				_tmp5_ = n;
				if (!(((guint) _tmp4_) < _tmp5_)) {
					break;
				}
				_tmp6_ = func;
				_tmp6__target = func_target;
				_tmp7_ = self->priv->store;
				_tmp8_ = i;
				_tmp9_ = g_list_model_get_object ((GListModel*) _tmp7_, (guint) _tmp8_);
				_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, CLOCKS_TYPE_CONTENT_ITEM) ? ((ClocksContentItem*) _tmp9_) : NULL;
				if (_tmp10_ == NULL) {
					_g_object_unref0 (_tmp9_);
				}
				_tmp11_ = _tmp10_;
				_tmp6_ (_tmp11_, _tmp6__target);
				_g_object_unref0 (_tmp11_);
			}
		}
	}
}


ClocksContentItem* clocks_content_store_find (ClocksContentStore* self, ClocksContentStoreFindFunc func, void* func_target) {
	ClocksContentItem* result = NULL;
	guint n = 0U;
	GListStore* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->store;
	_tmp1_ = g_list_model_get_n_items ((GListModel*) _tmp0_);
	n = _tmp1_;
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp2_ = FALSE;
			_tmp2_ = TRUE;
			while (TRUE) {
				gint _tmp4_ = 0;
				guint _tmp5_ = 0U;
				ClocksContentItem* item = NULL;
				GListStore* _tmp6_ = NULL;
				gint _tmp7_ = 0;
				GObject* _tmp8_ = NULL;
				ClocksContentItem* _tmp9_ = NULL;
				ClocksContentStoreFindFunc _tmp10_ = NULL;
				void* _tmp10__target = NULL;
				ClocksContentItem* _tmp11_ = NULL;
				gboolean _tmp12_ = FALSE;
				if (!_tmp2_) {
					gint _tmp3_ = 0;
					_tmp3_ = i;
					i = _tmp3_ + 1;
				}
				_tmp2_ = FALSE;
				_tmp4_ = i;
				_tmp5_ = n;
				if (!(((guint) _tmp4_) < _tmp5_)) {
					break;
				}
				_tmp6_ = self->priv->store;
				_tmp7_ = i;
				_tmp8_ = g_list_model_get_object ((GListModel*) _tmp6_, (guint) _tmp7_);
				_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, CLOCKS_TYPE_CONTENT_ITEM) ? ((ClocksContentItem*) _tmp8_) : NULL;
				if (_tmp9_ == NULL) {
					_g_object_unref0 (_tmp8_);
				}
				item = _tmp9_;
				_tmp10_ = func;
				_tmp10__target = func_target;
				_tmp11_ = item;
				_tmp12_ = _tmp10_ (_tmp11_, _tmp10__target);
				if (_tmp12_) {
					result = item;
					return result;
				}
				_g_object_unref0 (item);
			}
		}
	}
	result = NULL;
	return result;
}


guint clocks_content_store_get_n_selected (ClocksContentStore* self) {
	guint result = 0U;
	guint n_selected = 0U;
	guint n = 0U;
	GListStore* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	g_return_val_if_fail (self != NULL, 0U);
	n_selected = (guint) 0;
	_tmp0_ = self->priv->store;
	_tmp1_ = g_list_model_get_n_items ((GListModel*) _tmp0_);
	n = _tmp1_;
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp2_ = FALSE;
			_tmp2_ = TRUE;
			while (TRUE) {
				gint _tmp4_ = 0;
				guint _tmp5_ = 0U;
				ClocksContentItem* item = NULL;
				GListStore* _tmp6_ = NULL;
				gint _tmp7_ = 0;
				GObject* _tmp8_ = NULL;
				ClocksContentItem* _tmp9_ = NULL;
				ClocksContentItem* _tmp10_ = NULL;
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				if (!_tmp2_) {
					gint _tmp3_ = 0;
					_tmp3_ = i;
					i = _tmp3_ + 1;
				}
				_tmp2_ = FALSE;
				_tmp4_ = i;
				_tmp5_ = n;
				if (!(((guint) _tmp4_) < _tmp5_)) {
					break;
				}
				_tmp6_ = self->priv->store;
				_tmp7_ = i;
				_tmp8_ = g_list_model_get_object ((GListModel*) _tmp6_, (guint) _tmp7_);
				_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, CLOCKS_TYPE_CONTENT_ITEM) ? ((ClocksContentItem*) _tmp8_) : NULL;
				if (_tmp9_ == NULL) {
					_g_object_unref0 (_tmp8_);
				}
				item = _tmp9_;
				_tmp10_ = item;
				_tmp11_ = clocks_content_item_get_selected (_tmp10_);
				_tmp12_ = _tmp11_;
				if (_tmp12_) {
					guint _tmp13_ = 0U;
					_tmp13_ = n_selected;
					n_selected = _tmp13_ + 1;
				}
				_g_object_unref0 (item);
			}
		}
	}
	result = n_selected;
	return result;
}


static void _vala_array_add2 (GObject*** array, int* length, int* size, GObject* value) {
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (GObject*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}


void clocks_content_store_delete_selected (ClocksContentStore* self) {
	guint n_deleted = 0U;
	GObject** not_selected = NULL;
	GObject** _tmp0_ = NULL;
	gint not_selected_length1 = 0;
	gint _not_selected_size_ = 0;
	guint n = 0U;
	GListStore* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
	guint _tmp18_ = 0U;
	g_return_if_fail (self != NULL);
	n_deleted = (guint) 0;
	_tmp0_ = g_new0 (GObject*, 0 + 1);
	not_selected = _tmp0_;
	not_selected_length1 = 0;
	_not_selected_size_ = not_selected_length1;
	_tmp1_ = self->priv->store;
	_tmp2_ = g_list_model_get_n_items ((GListModel*) _tmp1_);
	n = _tmp2_;
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp3_ = FALSE;
			_tmp3_ = TRUE;
			while (TRUE) {
				gint _tmp5_ = 0;
				guint _tmp6_ = 0U;
				GObject* o = NULL;
				GListStore* _tmp7_ = NULL;
				gint _tmp8_ = 0;
				GObject* _tmp9_ = NULL;
				GObject* _tmp10_ = NULL;
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				if (!_tmp3_) {
					gint _tmp4_ = 0;
					_tmp4_ = i;
					i = _tmp4_ + 1;
				}
				_tmp3_ = FALSE;
				_tmp5_ = i;
				_tmp6_ = n;
				if (!(((guint) _tmp5_) < _tmp6_)) {
					break;
				}
				_tmp7_ = self->priv->store;
				_tmp8_ = i;
				_tmp9_ = g_list_model_get_object ((GListModel*) _tmp7_, (guint) _tmp8_);
				o = _tmp9_;
				_tmp10_ = o;
				_tmp11_ = clocks_content_item_get_selected (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, CLOCKS_TYPE_CONTENT_ITEM, ClocksContentItem));
				_tmp12_ = _tmp11_;
				if (!_tmp12_) {
					GObject** _tmp13_ = NULL;
					gint _tmp13__length1 = 0;
					GObject* _tmp14_ = NULL;
					GObject* _tmp15_ = NULL;
					_tmp13_ = not_selected;
					_tmp13__length1 = not_selected_length1;
					_tmp14_ = o;
					_tmp15_ = _g_object_ref0 (_tmp14_);
					_vala_array_add2 (&not_selected, &not_selected_length1, &_not_selected_size_, _tmp15_);
				} else {
					guint _tmp16_ = 0U;
					GObject* _tmp17_ = NULL;
					_tmp16_ = n_deleted;
					n_deleted = _tmp16_ + 1;
					_tmp17_ = o;
					g_signal_handlers_disconnect_by_func (_tmp17_, (void*) clocks_content_store_on_item_selection_toggle, (void*) self);
				}
				_g_object_unref0 (o);
			}
		}
	}
	_tmp18_ = n_deleted;
	if (_tmp18_ > ((guint) 0)) {
		GListStore* _tmp19_ = NULL;
		guint _tmp20_ = 0U;
		GObject** _tmp21_ = NULL;
		gint _tmp21__length1 = 0;
		_tmp19_ = self->priv->store;
		_tmp20_ = n;
		_tmp21_ = not_selected;
		_tmp21__length1 = not_selected_length1;
		g_list_store_splice (_tmp19_, (guint) 0, _tmp20_, _tmp21_, (guint) _tmp21__length1);
		g_signal_emit_by_name (self, "selection-changed");
	}
	not_selected = (_vala_array_free (not_selected, not_selected_length1, (GDestroyNotify) g_object_unref), NULL);
}


static void clocks_content_store_select_unselect_all (ClocksContentStore* self, gboolean select) {
	guint n_toggled = 0U;
	guint n = 0U;
	GListStore* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	guint _tmp24_ = 0U;
	g_return_if_fail (self != NULL);
	n_toggled = (guint) 0;
	_tmp0_ = self->priv->store;
	_tmp1_ = g_list_model_get_n_items ((GListModel*) _tmp0_);
	n = _tmp1_;
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp2_ = FALSE;
			_tmp2_ = TRUE;
			while (TRUE) {
				gint _tmp4_ = 0;
				guint _tmp5_ = 0U;
				ClocksContentItem* item = NULL;
				GListStore* _tmp6_ = NULL;
				gint _tmp7_ = 0;
				GObject* _tmp8_ = NULL;
				ClocksContentItem* _tmp9_ = NULL;
				gboolean _tmp10_ = FALSE;
				ClocksContentItem* _tmp11_ = NULL;
				gboolean _tmp12_ = FALSE;
				gboolean _tmp13_ = FALSE;
				gboolean selected = FALSE;
				gboolean _tmp15_ = FALSE;
				ClocksContentItem* _tmp16_ = NULL;
				gboolean _tmp17_ = FALSE;
				gboolean _tmp18_ = FALSE;
				if (!_tmp2_) {
					gint _tmp3_ = 0;
					_tmp3_ = i;
					i = _tmp3_ + 1;
				}
				_tmp2_ = FALSE;
				_tmp4_ = i;
				_tmp5_ = n;
				if (!(((guint) _tmp4_) < _tmp5_)) {
					break;
				}
				_tmp6_ = self->priv->store;
				_tmp7_ = i;
				_tmp8_ = g_list_model_get_object ((GListModel*) _tmp6_, (guint) _tmp7_);
				_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, CLOCKS_TYPE_CONTENT_ITEM) ? ((ClocksContentItem*) _tmp8_) : NULL;
				if (_tmp9_ == NULL) {
					_g_object_unref0 (_tmp8_);
				}
				item = _tmp9_;
				_tmp11_ = item;
				_tmp12_ = clocks_content_item_get_selectable (_tmp11_);
				_tmp13_ = _tmp12_;
				if (_tmp13_) {
					gboolean _tmp14_ = FALSE;
					_tmp14_ = select;
					_tmp10_ = _tmp14_;
				} else {
					_tmp10_ = FALSE;
				}
				selected = _tmp10_;
				_tmp15_ = selected;
				_tmp16_ = item;
				_tmp17_ = clocks_content_item_get_selected (_tmp16_);
				_tmp18_ = _tmp17_;
				if (_tmp15_ != _tmp18_) {
					ClocksContentItem* _tmp19_ = NULL;
					ClocksContentItem* _tmp20_ = NULL;
					gboolean _tmp21_ = FALSE;
					ClocksContentItem* _tmp22_ = NULL;
					guint _tmp23_ = 0U;
					_tmp19_ = item;
					g_signal_handlers_block_by_func (_tmp19_, (void*) clocks_content_store_on_item_selection_toggle, (void*) self);
					_tmp20_ = item;
					_tmp21_ = selected;
					clocks_content_item_set_selected (_tmp20_, _tmp21_);
					_tmp22_ = item;
					g_signal_handlers_unblock_by_func (_tmp22_, (void*) clocks_content_store_on_item_selection_toggle, (void*) self);
					_tmp23_ = n_toggled;
					n_toggled = _tmp23_ + 1;
				}
				_g_object_unref0 (item);
			}
		}
	}
	_tmp24_ = n_toggled;
	if (_tmp24_ > ((guint) 0)) {
		g_signal_emit_by_name (self, "selection-changed");
	}
}


void clocks_content_store_select_all (ClocksContentStore* self) {
	g_return_if_fail (self != NULL);
	clocks_content_store_select_unselect_all (self, TRUE);
}


void clocks_content_store_unselect_all (ClocksContentStore* self) {
	g_return_if_fail (self != NULL);
	clocks_content_store_select_unselect_all (self, FALSE);
}


GVariant* clocks_content_store_serialize (ClocksContentStore* self) {
	GVariant* result = NULL;
	GVariantBuilder* builder = NULL;
	GVariantType* _tmp0_ = NULL;
	GVariantType* _tmp1_ = NULL;
	GVariantBuilder* _tmp2_ = NULL;
	GVariantBuilder* _tmp3_ = NULL;
	guint n = 0U;
	GListStore* _tmp4_ = NULL;
	guint _tmp5_ = 0U;
	GVariantBuilder* _tmp16_ = NULL;
	GVariant* _tmp17_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = g_variant_type_new ("aa{sv}");
	_tmp1_ = _tmp0_;
	_tmp2_ = g_variant_builder_new (_tmp1_);
	_tmp3_ = _tmp2_;
	_g_variant_type_free0 (_tmp1_);
	builder = _tmp3_;
	_tmp4_ = self->priv->store;
	_tmp5_ = g_list_model_get_n_items ((GListModel*) _tmp4_);
	n = _tmp5_;
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp6_ = FALSE;
			_tmp6_ = TRUE;
			while (TRUE) {
				gint _tmp8_ = 0;
				guint _tmp9_ = 0U;
				ClocksContentItem* item = NULL;
				GListStore* _tmp10_ = NULL;
				gint _tmp11_ = 0;
				GObject* _tmp12_ = NULL;
				ClocksContentItem* _tmp13_ = NULL;
				ClocksContentItem* _tmp14_ = NULL;
				GVariantBuilder* _tmp15_ = NULL;
				if (!_tmp6_) {
					gint _tmp7_ = 0;
					_tmp7_ = i;
					i = _tmp7_ + 1;
				}
				_tmp6_ = FALSE;
				_tmp8_ = i;
				_tmp9_ = n;
				if (!(((guint) _tmp8_) < _tmp9_)) {
					break;
				}
				_tmp10_ = self->priv->store;
				_tmp11_ = i;
				_tmp12_ = g_list_model_get_object ((GListModel*) _tmp10_, (guint) _tmp11_);
				_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, CLOCKS_TYPE_CONTENT_ITEM) ? ((ClocksContentItem*) _tmp12_) : NULL;
				if (_tmp13_ == NULL) {
					_g_object_unref0 (_tmp12_);
				}
				item = _tmp13_;
				_tmp14_ = item;
				_tmp15_ = builder;
				clocks_content_item_serialize (_tmp14_, _tmp15_);
				_g_object_unref0 (item);
			}
		}
	}
	_tmp16_ = builder;
	_tmp17_ = g_variant_builder_end (_tmp16_);
	g_variant_ref_sink (_tmp17_);
	result = _tmp17_;
	_g_variant_builder_unref0 (builder);
	return result;
}


void clocks_content_store_deserialize (ClocksContentStore* self, GVariant* variant, ClocksContentStoreDeserializeItemFunc deserialize_item, void* deserialize_item_target) {
	g_return_if_fail (self != NULL);
	g_return_if_fail (variant != NULL);
	{
		GVariantIter* _v_it = NULL;
		GVariant* _tmp0_ = NULL;
		GVariantIter* _tmp1_ = NULL;
		GVariant* v = NULL;
		_tmp0_ = variant;
		_tmp1_ = g_variant_iter_new (_tmp0_);
		_v_it = _tmp1_;
		while (TRUE) {
			GVariantIter* _tmp2_ = NULL;
			GVariant* _tmp3_ = NULL;
			GVariant* _tmp4_ = NULL;
			ClocksContentItem* i = NULL;
			ClocksContentStoreDeserializeItemFunc _tmp5_ = NULL;
			void* _tmp5__target = NULL;
			GVariant* _tmp6_ = NULL;
			ClocksContentItem* _tmp7_ = NULL;
			ClocksContentItem* _tmp8_ = NULL;
			_tmp2_ = _v_it;
			_tmp3_ = g_variant_iter_next_value (_tmp2_);
			_g_variant_unref0 (v);
			v = _tmp3_;
			_tmp4_ = v;
			if (!(_tmp4_ != NULL)) {
				break;
			}
			_tmp5_ = deserialize_item;
			_tmp5__target = deserialize_item_target;
			_tmp6_ = v;
			_tmp7_ = _tmp5_ (_tmp6_, _tmp5__target);
			i = _tmp7_;
			_tmp8_ = i;
			if (_tmp8_ != NULL) {
				ClocksContentItem* _tmp9_ = NULL;
				_tmp9_ = i;
				clocks_content_store_add (self, _tmp9_);
			}
			_g_object_unref0 (i);
		}
		_g_variant_unref0 (v);
		_g_variant_iter_free0 (_v_it);
	}
}


static void clocks_content_store_class_init (ClocksContentStoreClass * klass) {
	clocks_content_store_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ClocksContentStorePrivate));
	G_OBJECT_CLASS (klass)->finalize = clocks_content_store_finalize;
	g_signal_new ("selection_changed", CLOCKS_TYPE_CONTENT_STORE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}


static void clocks_content_store_g_list_model_interface_init (GListModelInterface * iface) {
	clocks_content_store_g_list_model_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_item_type = (GType (*)(GListModel*)) clocks_content_store_real_get_item_type;
	iface->get_n_items = (guint (*)(GListModel*)) clocks_content_store_real_get_n_items;
	iface->get_item = (GObject* (*)(GListModel*, guint)) clocks_content_store_real_get_item;
}


static void clocks_content_store_instance_init (ClocksContentStore * self) {
	self->priv = CLOCKS_CONTENT_STORE_GET_PRIVATE (self);
}


static void clocks_content_store_finalize (GObject* obj) {
	ClocksContentStore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CLOCKS_TYPE_CONTENT_STORE, ClocksContentStore);
	_g_object_unref0 (self->priv->store);
	(self->priv->sort_func_target_destroy_notify == NULL) ? NULL : (self->priv->sort_func_target_destroy_notify (self->priv->sort_func_target), NULL);
	self->priv->sort_func = NULL;
	self->priv->sort_func_target = NULL;
	self->priv->sort_func_target_destroy_notify = NULL;
	G_OBJECT_CLASS (clocks_content_store_parent_class)->finalize (obj);
}


GType clocks_content_store_get_type (void) {
	static volatile gsize clocks_content_store_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_content_store_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ClocksContentStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) clocks_content_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ClocksContentStore), 0, (GInstanceInitFunc) clocks_content_store_instance_init, NULL };
		static const GInterfaceInfo g_list_model_info = { (GInterfaceInitFunc) clocks_content_store_g_list_model_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType clocks_content_store_type_id;
		clocks_content_store_type_id = g_type_register_static (G_TYPE_OBJECT, "ClocksContentStore", &g_define_type_info, 0);
		g_type_add_interface_static (clocks_content_store_type_id, g_list_model_get_type (), &g_list_model_info);
		g_once_init_leave (&clocks_content_store_type_id__volatile, clocks_content_store_type_id);
	}
	return clocks_content_store_type_id__volatile;
}


GType clocks_icon_view_mode_get_type (void) {
	static volatile gsize clocks_icon_view_mode_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_icon_view_mode_type_id__volatile)) {
		static const GEnumValue values[] = {{CLOCKS_ICON_VIEW_MODE_NORMAL, "CLOCKS_ICON_VIEW_MODE_NORMAL", "normal"}, {CLOCKS_ICON_VIEW_MODE_SELECTION, "CLOCKS_ICON_VIEW_MODE_SELECTION", "selection"}, {0, NULL, NULL}};
		GType clocks_icon_view_mode_type_id;
		clocks_icon_view_mode_type_id = g_enum_register_static ("ClocksIconViewMode", values);
		g_once_init_leave (&clocks_icon_view_mode_type_id__volatile, clocks_icon_view_mode_type_id);
	}
	return clocks_icon_view_mode_type_id__volatile;
}


static void __lambda11_ (ClocksIconView* self, GtkCellLayout* column, GtkCellRenderer* cell, GtkTreeModel* model, GtkTreeIter* iter) {
	ClocksContentItem* item = NULL;
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	ClocksContentItem* _tmp2_ = NULL;
	g_return_if_fail (column != NULL);
	g_return_if_fail (cell != NULL);
	g_return_if_fail (model != NULL);
	g_return_if_fail (iter != NULL);
	_tmp0_ = model;
	_tmp1_ = *iter;
	gtk_tree_model_get (_tmp0_, &_tmp1_, 0, &item, -1);
	_tmp2_ = item;
	if (_tmp2_ != NULL) {
		ClocksDigitalClockRenderer* renderer = NULL;
		GtkCellRenderer* _tmp3_ = NULL;
		ClocksDigitalClockRenderer* _tmp4_ = NULL;
		gchar* text = NULL;
		gchar* subtext = NULL;
		GdkPixbuf* pixbuf = NULL;
		gchar* css_class = NULL;
		ClocksContentItem* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GdkPixbuf* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		ClocksDigitalClockRenderer* _tmp10_ = NULL;
		ClocksContentItem* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
		gboolean _tmp13_ = FALSE;
		ClocksDigitalClockRenderer* _tmp14_ = NULL;
		ClocksIconViewMode _tmp15_ = 0;
		ClocksDigitalClockRenderer* _tmp16_ = NULL;
		ClocksContentItem* _tmp17_ = NULL;
		gboolean _tmp18_ = FALSE;
		gboolean _tmp19_ = FALSE;
		ClocksDigitalClockRenderer* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		ClocksDigitalClockRenderer* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		ClocksDigitalClockRenderer* _tmp24_ = NULL;
		GdkPixbuf* _tmp25_ = NULL;
		ClocksDigitalClockRenderer* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
		_tmp3_ = cell;
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, CLOCKS_TYPE_DIGITAL_CLOCK_RENDERER, ClocksDigitalClockRenderer));
		renderer = _tmp4_;
		_tmp5_ = item;
		clocks_content_item_get_thumb_properties (_tmp5_, &_tmp6_, &_tmp7_, &_tmp8_, &_tmp9_);
		_g_free0 (text);
		text = _tmp6_;
		_g_free0 (subtext);
		subtext = _tmp7_;
		_g_object_unref0 (pixbuf);
		pixbuf = _tmp8_;
		_g_free0 (css_class);
		css_class = _tmp9_;
		_tmp10_ = renderer;
		_tmp11_ = item;
		_tmp12_ = clocks_content_item_get_selectable (_tmp11_);
		_tmp13_ = _tmp12_;
		clocks_digital_clock_renderer_set_selectable (_tmp10_, _tmp13_);
		_tmp14_ = renderer;
		_tmp15_ = self->priv->_mode;
		clocks_digital_clock_renderer_set_toggle_visible (_tmp14_, _tmp15_ == CLOCKS_ICON_VIEW_MODE_SELECTION);
		_tmp16_ = renderer;
		_tmp17_ = item;
		_tmp18_ = clocks_content_item_get_selected (_tmp17_);
		_tmp19_ = _tmp18_;
		clocks_digital_clock_renderer_set_checked (_tmp16_, _tmp19_);
		_tmp20_ = renderer;
		_tmp21_ = text;
		clocks_digital_clock_renderer_set_text (_tmp20_, _tmp21_);
		_tmp22_ = renderer;
		_tmp23_ = subtext;
		clocks_digital_clock_renderer_set_subtext (_tmp22_, _tmp23_);
		_tmp24_ = renderer;
		_tmp25_ = pixbuf;
		g_object_set ((GtkCellRendererPixbuf*) _tmp24_, "pixbuf", _tmp25_, NULL);
		_tmp26_ = renderer;
		_tmp27_ = css_class;
		clocks_digital_clock_renderer_set_css_class (_tmp26_, _tmp27_);
		_g_free0 (css_class);
		_g_object_unref0 (pixbuf);
		_g_free0 (subtext);
		_g_free0 (text);
		_g_object_unref0 (renderer);
	}
	_g_object_unref0 (item);
}


static void ___lambda11__gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self) {
	__lambda11_ ((ClocksIconView*) self, cell_layout, cell, tree_model, iter);
}


static void __lambda12_ (ClocksIconView* self, GtkCellLayout* column, GtkCellRenderer* cell, GtkTreeModel* model, GtkTreeIter* iter) {
	ClocksContentItem* item = NULL;
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	ClocksContentItem* _tmp2_ = NULL;
	g_return_if_fail (column != NULL);
	g_return_if_fail (cell != NULL);
	g_return_if_fail (model != NULL);
	g_return_if_fail (iter != NULL);
	_tmp0_ = model;
	_tmp1_ = *iter;
	gtk_tree_model_get (_tmp0_, &_tmp1_, 0, &item, -1);
	_tmp2_ = item;
	if (_tmp2_ != NULL) {
		ClocksTitleRenderer* renderer = NULL;
		GtkCellRenderer* _tmp3_ = NULL;
		ClocksTitleRenderer* _tmp4_ = NULL;
		ClocksTitleRenderer* _tmp5_ = NULL;
		ClocksContentItem* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		ClocksTitleRenderer* _tmp11_ = NULL;
		ClocksContentItem* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		_tmp3_ = cell;
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, CLOCKS_TYPE_TITLE_RENDERER, ClocksTitleRenderer));
		renderer = _tmp4_;
		_tmp5_ = renderer;
		_tmp6_ = item;
		_tmp7_ = clocks_content_item_get_name (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = g_markup_escape_text (_tmp8_, (gssize) -1);
		_tmp10_ = _tmp9_;
		clocks_title_renderer_set_title (_tmp5_, _tmp10_);
		_g_free0 (_tmp10_);
		_tmp11_ = renderer;
		_tmp12_ = item;
		_tmp13_ = clocks_content_item_get_title_icon (_tmp12_);
		_tmp14_ = _tmp13_;
		clocks_title_renderer_set_title_icon (_tmp11_, _tmp14_);
		_g_object_unref0 (renderer);
	}
	_g_object_unref0 (item);
}


static void ___lambda12__gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self) {
	__lambda12_ ((ClocksIconView*) self, cell_layout, cell, tree_model, iter);
}


ClocksIconView* clocks_icon_view_construct (GType object_type) {
	ClocksIconView * self = NULL;
	GtkListStore* _tmp0_ = NULL;
	GtkListStore* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	GtkStyleContext* _tmp3_ = NULL;
	gint tile_width = 0;
	gint tile_height = 0;
	ClocksDigitalClockRenderer* thumb_renderer = NULL;
	ClocksDigitalClockRenderer* _tmp4_ = NULL;
	ClocksTitleRenderer* title_renderer = NULL;
	ClocksTitleRenderer* _tmp5_ = NULL;
	self = (ClocksIconView*) g_object_new (object_type, "selection-mode", GTK_SELECTION_NONE, "mode", CLOCKS_ICON_VIEW_MODE_NORMAL, NULL);
	_tmp0_ = gtk_list_store_new (1, CLOCKS_TYPE_CONTENT_ITEM, -1);
	_tmp1_ = _tmp0_;
	gtk_icon_view_set_model ((GtkIconView*) self, (GtkTreeModel*) _tmp1_);
	_g_object_unref0 (_tmp1_);
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) self);
	gtk_style_context_add_class (_tmp2_, "clocks-tiles-view");
	_tmp3_ = gtk_widget_get_style_context ((GtkWidget*) self);
	gtk_style_context_add_class (_tmp3_, "content-view");
	gtk_icon_view_set_item_padding ((GtkIconView*) self, 0);
	gtk_icon_view_set_margin ((GtkIconView*) self, 12);
	tile_width = CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_SIZE + (2 * CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_MARGIN);
	tile_height = (CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_SIZE + CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_MARGIN) + CLOCKS_DIGITAL_CLOCK_RENDERER_TILE_MARGIN_BOTTOM;
	_tmp4_ = clocks_digital_clock_renderer_new ();
	g_object_ref_sink (_tmp4_);
	thumb_renderer = _tmp4_;
	gtk_cell_renderer_set_alignment ((GtkCellRenderer*) thumb_renderer, 0.5f, 0.5f);
	gtk_cell_renderer_set_fixed_size ((GtkCellRenderer*) thumb_renderer, tile_width, tile_height);
	gtk_cell_layout_pack_start ((GtkCellLayout*) self, (GtkCellRenderer*) thumb_renderer, FALSE);
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) self, (GtkCellRenderer*) thumb_renderer, ___lambda11__gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
	_tmp5_ = clocks_title_renderer_new ();
	g_object_ref_sink (_tmp5_);
	title_renderer = _tmp5_;
	gtk_cell_renderer_set_alignment ((GtkCellRenderer*) title_renderer, 0.5f, 0.5f);
	gtk_cell_renderer_set_fixed_size ((GtkCellRenderer*) title_renderer, tile_width, -1);
	g_object_set ((GtkCellRendererText*) title_renderer, "alignment", PANGO_ALIGN_CENTER, NULL);
	g_object_set ((GtkCellRendererText*) title_renderer, "wrap-width", 220, NULL);
	g_object_set ((GtkCellRendererText*) title_renderer, "wrap-mode", PANGO_WRAP_WORD_CHAR, NULL);
	gtk_cell_layout_pack_start ((GtkCellLayout*) self, (GtkCellRenderer*) title_renderer, TRUE);
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) self, (GtkCellRenderer*) title_renderer, ___lambda12__gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
	_g_object_unref0 (title_renderer);
	_g_object_unref0 (thumb_renderer);
	return self;
}


ClocksIconView* clocks_icon_view_new (void) {
	return clocks_icon_view_construct (CLOCKS_TYPE_ICON_VIEW);
}


static gboolean clocks_icon_view_real_button_press_event (GtkWidget* base, GdkEventButton* event) {
	ClocksIconView * self;
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GdkEventButton* _tmp0_ = NULL;
	gdouble _tmp1_ = 0.0;
	GdkEventButton* _tmp2_ = NULL;
	gdouble _tmp3_ = 0.0;
	GtkTreePath* _tmp4_ = NULL;
	GtkTreePath* _tmp5_ = NULL;
	self = (ClocksIconView*) base;
	g_return_val_if_fail (event != NULL, FALSE);
	_tmp0_ = event;
	_tmp1_ = _tmp0_->x;
	_tmp2_ = event;
	_tmp3_ = _tmp2_->y;
	_tmp4_ = gtk_icon_view_get_path_at_pos ((GtkIconView*) self, (gint) _tmp1_, (gint) _tmp3_);
	path = _tmp4_;
	_tmp5_ = path;
	if (_tmp5_ != NULL) {
		GtkListStore* store = NULL;
		GtkTreeModel* _tmp6_ = NULL;
		GtkTreeModel* _tmp7_ = NULL;
		GtkListStore* _tmp8_ = NULL;
		GtkTreeIter i = {0};
		GtkListStore* _tmp9_ = NULL;
		GtkTreePath* _tmp10_ = NULL;
		GtkTreeIter _tmp11_ = {0};
		gboolean _tmp12_ = FALSE;
		_tmp6_ = gtk_icon_view_get_model ((GtkIconView*) self);
		_tmp7_ = _tmp6_;
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_list_store_get_type (), GtkListStore));
		store = _tmp8_;
		_tmp9_ = store;
		_tmp10_ = path;
		_tmp12_ = gtk_tree_model_get_iter ((GtkTreeModel*) _tmp9_, &_tmp11_, _tmp10_);
		i = _tmp11_;
		if (_tmp12_) {
			ClocksContentItem* item = NULL;
			GtkListStore* _tmp13_ = NULL;
			GtkTreeIter _tmp14_ = {0};
			ClocksContentItem* _tmp15_ = NULL;
			_tmp13_ = store;
			_tmp14_ = i;
			gtk_tree_model_get ((GtkTreeModel*) _tmp13_, &_tmp14_, 0, &item, -1);
			_tmp15_ = item;
			if (_tmp15_ != NULL) {
				gboolean _tmp16_ = FALSE;
				ClocksContentItem* _tmp17_ = NULL;
				gboolean _tmp18_ = FALSE;
				gboolean _tmp19_ = FALSE;
				gboolean _tmp22_ = FALSE;
				ClocksContentItem* _tmp23_ = NULL;
				gboolean _tmp24_ = FALSE;
				gboolean _tmp25_ = FALSE;
				_tmp17_ = item;
				_tmp18_ = clocks_content_item_get_selectable (_tmp17_);
				_tmp19_ = _tmp18_;
				if (_tmp19_) {
					GdkEventButton* _tmp20_ = NULL;
					guint _tmp21_ = 0U;
					_tmp20_ = event;
					_tmp21_ = _tmp20_->button;
					_tmp16_ = _tmp21_ == ((guint) GDK_BUTTON_SECONDARY);
				} else {
					_tmp16_ = FALSE;
				}
				if (_tmp16_) {
					clocks_icon_view_set_mode (self, CLOCKS_ICON_VIEW_MODE_SELECTION);
				}
				_tmp23_ = item;
				_tmp24_ = clocks_content_item_get_selectable (_tmp23_);
				_tmp25_ = _tmp24_;
				if (_tmp25_) {
					ClocksIconViewMode _tmp26_ = 0;
					_tmp26_ = self->priv->_mode;
					_tmp22_ = _tmp26_ == CLOCKS_ICON_VIEW_MODE_SELECTION;
				} else {
					_tmp22_ = FALSE;
				}
				if (_tmp22_) {
					ClocksContentItem* _tmp27_ = NULL;
					ClocksContentItem* _tmp28_ = NULL;
					gboolean _tmp29_ = FALSE;
					gboolean _tmp30_ = FALSE;
					_tmp27_ = item;
					_tmp28_ = item;
					_tmp29_ = clocks_content_item_get_selected (_tmp28_);
					_tmp30_ = _tmp29_;
					clocks_content_item_set_selected (_tmp27_, !_tmp30_);
					g_signal_emit_by_name ((GtkIconView*) self, "selection-changed");
				} else {
					GdkEventButton* _tmp31_ = NULL;
					guint _tmp32_ = 0U;
					_tmp31_ = event;
					_tmp32_ = _tmp31_->button;
					if (_tmp32_ == ((guint) GDK_BUTTON_PRIMARY)) {
						GtkTreePath* _tmp33_ = NULL;
						_tmp33_ = path;
						gtk_icon_view_item_activated ((GtkIconView*) self, _tmp33_);
					}
				}
			}
			_g_object_unref0 (item);
		}
		_g_object_unref0 (store);
	}
	result = FALSE;
	_gtk_tree_path_free0 (path);
	return result;
}


void clocks_icon_view_add_item (ClocksIconView* self, GObject* item) {
	GtkListStore* store = NULL;
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeModel* _tmp1_ = NULL;
	GtkListStore* _tmp2_ = NULL;
	GtkTreeIter i = {0};
	GtkTreeIter _tmp3_ = {0};
	GtkTreeIter _tmp4_ = {0};
	GObject* _tmp5_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (item != NULL);
	_tmp0_ = gtk_icon_view_get_model ((GtkIconView*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_list_store_get_type (), GtkListStore));
	store = _tmp2_;
	gtk_list_store_append (store, &_tmp3_);
	i = _tmp3_;
	_tmp4_ = i;
	_tmp5_ = item;
	gtk_list_store_set (store, &_tmp4_, 0, _tmp5_, -1);
	_g_object_unref0 (store);
}


void clocks_icon_view_clear (ClocksIconView* self) {
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeModel* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = gtk_icon_view_get_model ((GtkIconView*) self);
	_tmp1_ = _tmp0_;
	gtk_list_store_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_list_store_get_type (), GtkListStore));
}


ClocksIconViewMode clocks_icon_view_get_mode (ClocksIconView* self) {
	ClocksIconViewMode result;
	ClocksIconViewMode _tmp0_ = 0;
	g_return_val_if_fail (self != NULL, 0);
	_tmp0_ = self->priv->_mode;
	result = _tmp0_;
	return result;
}


void clocks_icon_view_set_mode (ClocksIconView* self, ClocksIconViewMode value) {
	ClocksIconViewMode _tmp0_ = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->priv->_mode = _tmp0_;
	g_object_notify ((GObject *) self, "mode");
}


static void clocks_icon_view_class_init (ClocksIconViewClass * klass) {
	clocks_icon_view_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ClocksIconViewPrivate));
	((GtkWidgetClass *) klass)->button_press_event = clocks_icon_view_real_button_press_event;
	G_OBJECT_CLASS (klass)->get_property = _vala_clocks_icon_view_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_clocks_icon_view_set_property;
	G_OBJECT_CLASS (klass)->finalize = clocks_icon_view_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_ICON_VIEW_MODE, g_param_spec_enum ("mode", "mode", "mode", CLOCKS_ICON_VIEW_TYPE_MODE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void clocks_icon_view_instance_init (ClocksIconView * self) {
	self->priv = CLOCKS_ICON_VIEW_GET_PRIVATE (self);
}


static void clocks_icon_view_finalize (GObject* obj) {
	ClocksIconView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CLOCKS_TYPE_ICON_VIEW, ClocksIconView);
	G_OBJECT_CLASS (clocks_icon_view_parent_class)->finalize (obj);
}


GType clocks_icon_view_get_type (void) {
	static volatile gsize clocks_icon_view_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_icon_view_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ClocksIconViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) clocks_icon_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ClocksIconView), 0, (GInstanceInitFunc) clocks_icon_view_instance_init, NULL };
		GType clocks_icon_view_type_id;
		clocks_icon_view_type_id = g_type_register_static (gtk_icon_view_get_type (), "ClocksIconView", &g_define_type_info, 0);
		g_once_init_leave (&clocks_icon_view_type_id__volatile, clocks_icon_view_type_id);
	}
	return clocks_icon_view_type_id__volatile;
}


static void _vala_clocks_icon_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ClocksIconView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_ICON_VIEW, ClocksIconView);
	switch (property_id) {
		case CLOCKS_ICON_VIEW_MODE:
		g_value_set_enum (value, clocks_icon_view_get_mode (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_clocks_icon_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ClocksIconView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_ICON_VIEW, ClocksIconView);
	switch (property_id) {
		case CLOCKS_ICON_VIEW_MODE:
		clocks_icon_view_set_mode (self, g_value_get_enum (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


ClocksSelectionMenuButton* clocks_selection_menu_button_construct (GType object_type) {
	ClocksSelectionMenuButton * self = NULL;
	GtkApplication* app = NULL;
	GApplication* _tmp0_ = NULL;
	GtkApplication* _tmp1_ = NULL;
	GMenu* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GtkLabel* _tmp4_ = NULL;
	GtkImage* arrow = NULL;
	GtkImage* _tmp5_ = NULL;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp6_ = NULL;
	GtkLabel* _tmp7_ = NULL;
	GtkStyleContext* _tmp8_ = NULL;
	self = (ClocksSelectionMenuButton*) g_object_new (object_type, NULL);
	_tmp0_ = g_application_get_default ();
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_application_get_type (), GtkApplication));
	app = _tmp1_;
	_tmp2_ = gtk_application_get_menu_by_id (app, "selection-menu");
	gtk_menu_button_set_menu_model ((GtkMenuButton*) self, (GMenuModel*) _tmp2_);
	_tmp3_ = _ ("Click on items to select them");
	_tmp4_ = (GtkLabel*) gtk_label_new (_tmp3_);
	g_object_ref_sink (_tmp4_);
	_g_object_unref0 (self->priv->menubutton_label);
	self->priv->menubutton_label = _tmp4_;
	_tmp5_ = (GtkImage*) gtk_image_new_from_icon_name ("pan-down-symbolic", GTK_ICON_SIZE_BUTTON);
	g_object_ref_sink (_tmp5_);
	arrow = _tmp5_;
	_tmp6_ = (GtkGrid*) gtk_grid_new ();
	g_object_ref_sink (_tmp6_);
	grid = _tmp6_;
	gtk_grid_set_column_spacing (grid, (guint) 6);
	_tmp7_ = self->priv->menubutton_label;
	gtk_grid_attach (grid, (GtkWidget*) _tmp7_, 0, 0, 1, 1);
	gtk_grid_attach (grid, (GtkWidget*) arrow, 1, 0, 1, 1);
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) grid);
	gtk_widget_set_valign ((GtkWidget*) self, GTK_ALIGN_CENTER);
	_tmp8_ = gtk_widget_get_style_context ((GtkWidget*) self);
	gtk_style_context_add_class (_tmp8_, "selection-menu");
	gtk_widget_show_all ((GtkWidget*) self);
	_g_object_unref0 (grid);
	_g_object_unref0 (arrow);
	_g_object_unref0 (app);
	return self;
}


ClocksSelectionMenuButton* clocks_selection_menu_button_new (void) {
	return clocks_selection_menu_button_construct (CLOCKS_TYPE_SELECTION_MENU_BUTTON);
}


guint clocks_selection_menu_button_get_n_items (ClocksSelectionMenuButton* self) {
	guint result;
	guint _tmp0_ = 0U;
	g_return_val_if_fail (self != NULL, 0U);
	_tmp0_ = self->priv->_n_items;
	result = _tmp0_;
	return result;
}


void clocks_selection_menu_button_set_n_items (ClocksSelectionMenuButton* self, guint value) {
	guint _tmp0_ = 0U;
	guint _tmp1_ = 0U;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_n_items;
	_tmp1_ = value;
	if (_tmp0_ != _tmp1_) {
		guint _tmp2_ = 0U;
		gchar* label = NULL;
		guint _tmp3_ = 0U;
		guint _tmp4_ = 0U;
		GtkLabel* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		_tmp2_ = value;
		self->priv->_n_items = _tmp2_;
		_tmp3_ = clocks_selection_menu_button_get_n_items (self);
		_tmp4_ = _tmp3_;
		if (_tmp4_ == ((guint) 0)) {
			const gchar* _tmp5_ = NULL;
			gchar* _tmp6_ = NULL;
			_tmp5_ = _ ("Click on items to select them");
			_tmp6_ = g_strdup (_tmp5_);
			_g_free0 (label);
			label = _tmp6_;
		} else {
			guint _tmp7_ = 0U;
			guint _tmp8_ = 0U;
			const gchar* _tmp9_ = NULL;
			guint _tmp10_ = 0U;
			guint _tmp11_ = 0U;
			gchar* _tmp12_ = NULL;
			_tmp7_ = clocks_selection_menu_button_get_n_items (self);
			_tmp8_ = _tmp7_;
			_tmp9_ = ngettext ("%d selected", "%d selected", (gulong) _tmp8_);
			_tmp10_ = clocks_selection_menu_button_get_n_items (self);
			_tmp11_ = _tmp10_;
			_tmp12_ = g_strdup_printf (_tmp9_, _tmp11_);
			_g_free0 (label);
			label = _tmp12_;
		}
		_tmp13_ = self->priv->menubutton_label;
		_tmp14_ = label;
		gtk_label_set_label (_tmp13_, _tmp14_);
		_g_free0 (label);
	}
	g_object_notify ((GObject *) self, "n-items");
}


static void clocks_selection_menu_button_class_init (ClocksSelectionMenuButtonClass * klass) {
	clocks_selection_menu_button_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ClocksSelectionMenuButtonPrivate));
	G_OBJECT_CLASS (klass)->get_property = _vala_clocks_selection_menu_button_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_clocks_selection_menu_button_set_property;
	G_OBJECT_CLASS (klass)->finalize = clocks_selection_menu_button_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_SELECTION_MENU_BUTTON_N_ITEMS, g_param_spec_uint ("n-items", "n-items", "n-items", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void clocks_selection_menu_button_instance_init (ClocksSelectionMenuButton * self) {
	self->priv = CLOCKS_SELECTION_MENU_BUTTON_GET_PRIVATE (self);
}


static void clocks_selection_menu_button_finalize (GObject* obj) {
	ClocksSelectionMenuButton * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CLOCKS_TYPE_SELECTION_MENU_BUTTON, ClocksSelectionMenuButton);
	_g_object_unref0 (self->priv->menubutton_label);
	G_OBJECT_CLASS (clocks_selection_menu_button_parent_class)->finalize (obj);
}


GType clocks_selection_menu_button_get_type (void) {
	static volatile gsize clocks_selection_menu_button_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_selection_menu_button_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ClocksSelectionMenuButtonClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) clocks_selection_menu_button_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ClocksSelectionMenuButton), 0, (GInstanceInitFunc) clocks_selection_menu_button_instance_init, NULL };
		GType clocks_selection_menu_button_type_id;
		clocks_selection_menu_button_type_id = g_type_register_static (gtk_menu_button_get_type (), "ClocksSelectionMenuButton", &g_define_type_info, 0);
		g_once_init_leave (&clocks_selection_menu_button_type_id__volatile, clocks_selection_menu_button_type_id);
	}
	return clocks_selection_menu_button_type_id__volatile;
}


static void _vala_clocks_selection_menu_button_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ClocksSelectionMenuButton * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_SELECTION_MENU_BUTTON, ClocksSelectionMenuButton);
	switch (property_id) {
		case CLOCKS_SELECTION_MENU_BUTTON_N_ITEMS:
		g_value_set_uint (value, clocks_selection_menu_button_get_n_items (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_clocks_selection_menu_button_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ClocksSelectionMenuButton * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_SELECTION_MENU_BUTTON, ClocksSelectionMenuButton);
	switch (property_id) {
		case CLOCKS_SELECTION_MENU_BUTTON_N_ITEMS:
		clocks_selection_menu_button_set_n_items (self, g_value_get_uint (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static gboolean __lambda14_ (ClocksContentView* self, ClocksContentItem* i) {
	gboolean result = FALSE;
	ClocksContentItem* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	g_return_val_if_fail (i != NULL, FALSE);
	_tmp0_ = i;
	_tmp1_ = clocks_content_item_get_selectable (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}


static gboolean ___lambda14__clocks_content_store_find_func (ClocksContentItem* item, gpointer self) {
	gboolean result;
	result = __lambda14_ ((ClocksContentView*) self, item);
	return result;
}


static void __lambda15_ (ClocksContentView* self, ClocksContentItem* item) {
	ClocksIconView* _tmp0_ = NULL;
	ClocksContentItem* _tmp1_ = NULL;
	g_return_if_fail (item != NULL);
	_tmp0_ = self->priv->icon_view;
	_tmp1_ = item;
	clocks_icon_view_add_item (_tmp0_, (GObject*) _tmp1_);
}


static void ___lambda15__clocks_content_store_foreach_func (ClocksContentItem* item, gpointer self) {
	__lambda15_ ((ClocksContentView*) self, item);
}


static void __lambda13_ (ClocksContentView* self, guint position, guint removed, guint added) {
	ClocksContentItem* first_selectable = NULL;
	ClocksContentStore* _tmp0_ = NULL;
	ClocksContentItem* _tmp1_ = NULL;
	ClocksIconView* _tmp2_ = NULL;
	ClocksContentStore* _tmp3_ = NULL;
	_tmp0_ = self->priv->model;
	_tmp1_ = clocks_content_store_find (_tmp0_, ___lambda14__clocks_content_store_find_func, self);
	first_selectable = _tmp1_;
	clocks_content_view_set_can_select (self, first_selectable != NULL);
	_tmp2_ = self->priv->icon_view;
	clocks_icon_view_clear (_tmp2_);
	_tmp3_ = self->priv->model;
	clocks_content_store_foreach (_tmp3_, ___lambda15__clocks_content_store_foreach_func, self);
	_g_object_unref0 (first_selectable);
}


static void ___lambda13__g_list_model_items_changed (GListModel* _sender, guint position, guint removed, guint added, gpointer self) {
	__lambda13_ ((ClocksContentView*) self, position, removed, added);
}


static void __lambda16_ (ClocksContentView* self) {
	guint n_items = 0U;
	ClocksContentStore* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	ClocksSelectionMenuButton* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	guint _tmp4_ = 0U;
	_tmp0_ = self->priv->model;
	_tmp1_ = clocks_content_store_get_n_selected (_tmp0_);
	n_items = _tmp1_;
	_tmp2_ = self->priv->selection_menubutton;
	_tmp3_ = n_items;
	clocks_selection_menu_button_set_n_items (_tmp2_, _tmp3_);
	_tmp4_ = n_items;
	if (_tmp4_ != ((guint) 0)) {
		GtkButton* _tmp5_ = NULL;
		_tmp5_ = self->priv->delete_button;
		gtk_widget_set_sensitive ((GtkWidget*) _tmp5_, TRUE);
	} else {
		GtkButton* _tmp6_ = NULL;
		_tmp6_ = self->priv->delete_button;
		gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, FALSE);
	}
}


static void ___lambda16__clocks_content_store_selection_changed (ClocksContentStore* _sender, gpointer self) {
	__lambda16_ ((ClocksContentView*) self);
}


void clocks_content_view_bind_model (ClocksContentView* self, ClocksContentStore* store) {
	ClocksContentStore* _tmp0_ = NULL;
	ClocksContentStore* _tmp1_ = NULL;
	ClocksContentStore* _tmp2_ = NULL;
	ClocksContentStore* _tmp3_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (store != NULL);
	_tmp0_ = store;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (self->priv->model);
	self->priv->model = _tmp1_;
	_tmp2_ = self->priv->model;
	g_signal_connect_object ((GListModel*) _tmp2_, "items-changed", (GCallback) ___lambda13__g_list_model_items_changed, self, 0);
	_tmp3_ = self->priv->model;
	g_signal_connect_object (_tmp3_, "selection-changed", (GCallback) ___lambda16__clocks_content_store_selection_changed, self, 0);
}


void clocks_content_view_select_all (ClocksContentView* self) {
	ClocksIconView* _tmp0_ = NULL;
	ClocksContentStore* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->icon_view;
	clocks_icon_view_set_mode (_tmp0_, CLOCKS_ICON_VIEW_MODE_SELECTION);
	_tmp1_ = self->priv->model;
	clocks_content_store_select_all (_tmp1_);
}


void clocks_content_view_unselect_all (ClocksContentView* self) {
	ClocksContentStore* _tmp0_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->model;
	clocks_content_store_unselect_all (_tmp0_);
}


gboolean clocks_content_view_escape_pressed (ClocksContentView* self) {
	gboolean result = FALSE;
	ClocksIconView* _tmp0_ = NULL;
	ClocksIconViewMode _tmp1_ = 0;
	ClocksIconViewMode _tmp2_ = 0;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->icon_view;
	_tmp1_ = clocks_icon_view_get_mode (_tmp0_);
	_tmp2_ = _tmp1_;
	if (_tmp2_ == CLOCKS_ICON_VIEW_MODE_SELECTION) {
		ClocksIconView* _tmp3_ = NULL;
		_tmp3_ = self->priv->icon_view;
		clocks_icon_view_set_mode (_tmp3_, CLOCKS_ICON_VIEW_MODE_NORMAL);
		result = TRUE;
		return result;
	}
	result = FALSE;
	return result;
}


static void __lambda17_ (ClocksContentView* self) {
	ClocksIconView* _tmp0_ = NULL;
	_tmp0_ = self->priv->icon_view;
	clocks_icon_view_set_mode (_tmp0_, CLOCKS_ICON_VIEW_MODE_SELECTION);
}


static void ___lambda17__gtk_button_clicked (GtkButton* _sender, gpointer self) {
	__lambda17_ ((ClocksContentView*) self);
}


static void __lambda18_ (ClocksContentView* self) {
	ClocksIconView* _tmp0_ = NULL;
	_tmp0_ = self->priv->icon_view;
	clocks_icon_view_set_mode (_tmp0_, CLOCKS_ICON_VIEW_MODE_NORMAL);
}


static void ___lambda18__gtk_button_clicked (GtkButton* _sender, gpointer self) {
	__lambda18_ ((ClocksContentView*) self);
}


static void __lambda19_ (ClocksContentView* self) {
	ClocksIconView* _tmp0_ = NULL;
	ClocksIconViewMode _tmp1_ = 0;
	ClocksIconViewMode _tmp2_ = 0;
	_tmp0_ = self->priv->icon_view;
	_tmp1_ = clocks_icon_view_get_mode (_tmp0_);
	_tmp2_ = _tmp1_;
	if (_tmp2_ == CLOCKS_ICON_VIEW_MODE_SELECTION) {
		ClocksHeaderBar* _tmp3_ = NULL;
		_tmp3_ = self->priv->header_bar;
		clocks_header_bar_set_mode (_tmp3_, CLOCKS_HEADER_BAR_MODE_SELECTION);
	} else {
		ClocksIconView* _tmp4_ = NULL;
		ClocksIconViewMode _tmp5_ = 0;
		ClocksIconViewMode _tmp6_ = 0;
		_tmp4_ = self->priv->icon_view;
		_tmp5_ = clocks_icon_view_get_mode (_tmp4_);
		_tmp6_ = _tmp5_;
		if (_tmp6_ == CLOCKS_ICON_VIEW_MODE_NORMAL) {
			ClocksIconView* _tmp7_ = NULL;
			ClocksHeaderBar* _tmp8_ = NULL;
			_tmp7_ = self->priv->icon_view;
			g_signal_emit_by_name ((GtkIconView*) _tmp7_, "unselect-all");
			_tmp8_ = self->priv->header_bar;
			clocks_header_bar_set_mode (_tmp8_, CLOCKS_HEADER_BAR_MODE_NORMAL);
		}
	}
}


static void ___lambda19__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
	__lambda19_ ((ClocksContentView*) self);
}


void clocks_content_view_set_header_bar (ClocksContentView* self, ClocksHeaderBar* bar) {
	ClocksHeaderBar* _tmp0_ = NULL;
	ClocksHeaderBar* _tmp1_ = NULL;
	GtkButton* _tmp2_ = NULL;
	GtkImage* select_button_image = NULL;
	GtkImage* _tmp3_ = NULL;
	GtkButton* _tmp4_ = NULL;
	GtkButton* _tmp5_ = NULL;
	GtkButton* _tmp6_ = NULL;
	GtkButton* _tmp7_ = NULL;
	ClocksHeaderBar* _tmp8_ = NULL;
	GtkButton* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	GtkButton* _tmp11_ = NULL;
	GtkButton* _tmp12_ = NULL;
	GtkButton* _tmp13_ = NULL;
	GtkButton* _tmp14_ = NULL;
	ClocksHeaderBar* _tmp15_ = NULL;
	GtkButton* _tmp16_ = NULL;
	ClocksSelectionMenuButton* _tmp17_ = NULL;
	ClocksIconView* _tmp18_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (bar != NULL);
	_tmp0_ = bar;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (self->priv->header_bar);
	self->priv->header_bar = _tmp1_;
	_tmp2_ = (GtkButton*) gtk_button_new ();
	g_object_ref_sink (_tmp2_);
	_g_object_unref0 (self->priv->select_button);
	self->priv->select_button = _tmp2_;
	_tmp3_ = (GtkImage*) gtk_image_new_from_icon_name ("object-select-symbolic", GTK_ICON_SIZE_MENU);
	g_object_ref_sink (_tmp3_);
	select_button_image = _tmp3_;
	_tmp4_ = self->priv->select_button;
	gtk_button_set_image (_tmp4_, (GtkWidget*) select_button_image);
	_tmp5_ = self->priv->select_button;
	gtk_widget_set_valign ((GtkWidget*) _tmp5_, GTK_ALIGN_CENTER);
	_tmp6_ = self->priv->select_button;
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp6_, TRUE);
	_tmp7_ = self->priv->select_button;
	g_signal_connect_object (_tmp7_, "clicked", (GCallback) ___lambda17__gtk_button_clicked, self, 0);
	_tmp8_ = self->priv->header_bar;
	_tmp9_ = self->priv->select_button;
	gtk_header_bar_pack_end ((GtkHeaderBar*) _tmp8_, (GtkWidget*) _tmp9_);
	_tmp10_ = _ ("Cancel");
	_tmp11_ = (GtkButton*) gtk_button_new_with_label (_tmp10_);
	g_object_ref_sink (_tmp11_);
	_g_object_unref0 (self->priv->cancel_button);
	self->priv->cancel_button = _tmp11_;
	_tmp12_ = self->priv->cancel_button;
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp12_, TRUE);
	_tmp13_ = self->priv->cancel_button;
	gtk_widget_set_valign ((GtkWidget*) _tmp13_, GTK_ALIGN_CENTER);
	_tmp14_ = self->priv->cancel_button;
	g_signal_connect_object (_tmp14_, "clicked", (GCallback) ___lambda18__gtk_button_clicked, self, 0);
	_tmp15_ = self->priv->header_bar;
	_tmp16_ = self->priv->cancel_button;
	gtk_header_bar_pack_end ((GtkHeaderBar*) _tmp15_, (GtkWidget*) _tmp16_);
	_tmp17_ = clocks_selection_menu_button_new ();
	g_object_ref_sink (_tmp17_);
	_g_object_unref0 (self->priv->selection_menubutton);
	self->priv->selection_menubutton = _tmp17_;
	_tmp18_ = self->priv->icon_view;
	g_signal_connect_object ((GObject*) _tmp18_, "notify::mode", (GCallback) ___lambda19__g_object_notify, self, 0);
	_g_object_unref0 (select_button_image);
}


void clocks_content_view_update_header_bar (ClocksContentView* self) {
	ClocksHeaderBar* _tmp0_ = NULL;
	ClocksHeaderBarMode _tmp1_ = 0;
	ClocksHeaderBarMode _tmp2_ = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->header_bar;
	_tmp1_ = clocks_header_bar_get_mode (_tmp0_);
	_tmp2_ = _tmp1_;
	switch (_tmp2_) {
		case CLOCKS_HEADER_BAR_MODE_SELECTION:
		{
			ClocksHeaderBar* _tmp3_ = NULL;
			ClocksSelectionMenuButton* _tmp4_ = NULL;
			GtkButton* _tmp5_ = NULL;
			_tmp3_ = self->priv->header_bar;
			_tmp4_ = self->priv->selection_menubutton;
			gtk_header_bar_set_custom_title ((GtkHeaderBar*) _tmp3_, (GtkWidget*) _tmp4_);
			_tmp5_ = self->priv->cancel_button;
			gtk_widget_show ((GtkWidget*) _tmp5_);
			break;
		}
		case CLOCKS_HEADER_BAR_MODE_NORMAL:
		{
			GtkButton* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			gboolean _tmp8_ = FALSE;
			_tmp6_ = self->priv->select_button;
			_tmp7_ = clocks_content_view_get_can_select (self);
			_tmp8_ = _tmp7_;
			gtk_widget_set_visible ((GtkWidget*) _tmp6_, _tmp8_);
			break;
		}
		default:
		break;
	}
}


ClocksContentView* clocks_content_view_construct (GType object_type) {
	ClocksContentView * self = NULL;
	self = (ClocksContentView*) g_object_new (object_type, NULL);
	return self;
}


ClocksContentView* clocks_content_view_new (void) {
	return clocks_content_view_construct (CLOCKS_TYPE_CONTENT_VIEW);
}


static gboolean clocks_content_view_get_can_select (ClocksContentView* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->_can_select;
	result = _tmp0_;
	return result;
}


static void clocks_content_view_set_can_select (ClocksContentView* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_can_select;
	_tmp1_ = value;
	if (_tmp0_ != _tmp1_) {
		gboolean _tmp2_ = FALSE;
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
		GtkButton* _tmp6_ = NULL;
		_tmp2_ = value;
		self->priv->_can_select = _tmp2_;
		_tmp4_ = self->priv->_can_select;
		if (_tmp4_) {
			gboolean _tmp5_ = FALSE;
			_tmp5_ = gtk_widget_get_mapped ((GtkWidget*) self);
			_tmp3_ = _tmp5_;
		} else {
			_tmp3_ = FALSE;
		}
		_tmp6_ = self->priv->select_button;
		gtk_widget_set_visible ((GtkWidget*) _tmp6_, _tmp3_);
	}
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
	g_atomic_int_inc (&_data7_->_ref_count_);
	return _data7_;
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
		ClocksContentView* self;
		self = _data7_->self;
		_g_object_unref0 (_data7_->action_bar);
		_g_object_unref0 (self);
		g_slice_free (Block7Data, _data7_);
	}
}


static void _clocks_content_view___lambda20_ (ClocksContentView* self) {
	ClocksContentStore* _tmp0_ = NULL;
	ClocksIconView* _tmp1_ = NULL;
	_tmp0_ = self->priv->model;
	clocks_content_store_delete_selected (_tmp0_);
	_tmp1_ = self->priv->icon_view;
	clocks_icon_view_set_mode (_tmp1_, CLOCKS_ICON_VIEW_MODE_NORMAL);
}


static void __clocks_content_view___lambda20__gtk_button_clicked (GtkButton* _sender, gpointer self) {
	_clocks_content_view___lambda20_ ((ClocksContentView*) self);
}


static void _clocks_content_view___lambda21_ (Block7Data* _data7_) {
	ClocksContentView* self;
	ClocksIconView* _tmp0_ = NULL;
	ClocksIconViewMode _tmp1_ = 0;
	ClocksIconViewMode _tmp2_ = 0;
	self = _data7_->self;
	_tmp0_ = self->priv->icon_view;
	_tmp1_ = clocks_icon_view_get_mode (_tmp0_);
	_tmp2_ = _tmp1_;
	if (_tmp2_ == CLOCKS_ICON_VIEW_MODE_SELECTION) {
		GtkActionBar* _tmp3_ = NULL;
		_tmp3_ = _data7_->action_bar;
		gtk_widget_show ((GtkWidget*) _tmp3_);
	} else {
		ClocksIconView* _tmp4_ = NULL;
		ClocksIconViewMode _tmp5_ = 0;
		ClocksIconViewMode _tmp6_ = 0;
		_tmp4_ = self->priv->icon_view;
		_tmp5_ = clocks_icon_view_get_mode (_tmp4_);
		_tmp6_ = _tmp5_;
		if (_tmp6_ == CLOCKS_ICON_VIEW_MODE_NORMAL) {
			GtkActionBar* _tmp7_ = NULL;
			_tmp7_ = _data7_->action_bar;
			gtk_widget_hide ((GtkWidget*) _tmp7_);
		}
	}
}


static void __clocks_content_view___lambda21__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
	_clocks_content_view___lambda21_ (self);
}


static void _clocks_content_view___lambda22_ (ClocksContentView* self, GtkTreePath* path) {
	GtkListStore* store = NULL;
	ClocksIconView* _tmp0_ = NULL;
	GtkTreeModel* _tmp1_ = NULL;
	GtkTreeModel* _tmp2_ = NULL;
	GtkListStore* _tmp3_ = NULL;
	GtkTreeIter iter = {0};
	GtkListStore* _tmp4_ = NULL;
	GtkTreePath* _tmp5_ = NULL;
	GtkTreeIter _tmp6_ = {0};
	gboolean _tmp7_ = FALSE;
	g_return_if_fail (path != NULL);
	_tmp0_ = self->priv->icon_view;
	_tmp1_ = gtk_icon_view_get_model ((GtkIconView*) _tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_list_store_get_type (), GtkListStore));
	store = _tmp3_;
	_tmp4_ = store;
	_tmp5_ = path;
	_tmp7_ = gtk_tree_model_get_iter ((GtkTreeModel*) _tmp4_, &_tmp6_, _tmp5_);
	iter = _tmp6_;
	if (_tmp7_) {
		ClocksContentItem* item = NULL;
		GtkListStore* _tmp8_ = NULL;
		GtkTreeIter _tmp9_ = {0};
		ClocksContentItem* _tmp10_ = NULL;
		_tmp8_ = store;
		_tmp9_ = iter;
		gtk_tree_model_get ((GtkTreeModel*) _tmp8_, &_tmp9_, 0, &item, -1);
		_tmp10_ = item;
		if (_tmp10_ != NULL) {
			ClocksContentItem* _tmp11_ = NULL;
			_tmp11_ = item;
			g_signal_emit_by_name (self, "item-activated", _tmp11_);
		}
		_g_object_unref0 (item);
	}
	_g_object_unref0 (store);
}


static void __clocks_content_view___lambda22__gtk_icon_view_item_activated (GtkIconView* _sender, GtkTreePath* path, gpointer self) {
	_clocks_content_view___lambda22_ ((ClocksContentView*) self, path);
}


static GObject * clocks_content_view_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	ClocksContentView * self;
	Block7Data* _data7_;
	ClocksIconView* _tmp0_ = NULL;
	GtkScrolledWindow* scrolled_window = NULL;
	GtkScrolledWindow* _tmp1_ = NULL;
	GtkScrolledWindow* _tmp2_ = NULL;
	ClocksIconView* _tmp3_ = NULL;
	GtkScrolledWindow* _tmp4_ = NULL;
	GtkScrolledWindow* _tmp5_ = NULL;
	GtkScrolledWindow* _tmp6_ = NULL;
	GtkScrolledWindow* _tmp7_ = NULL;
	GtkGrid* _tmp8_ = NULL;
	GtkGrid* _tmp9_ = NULL;
	GtkScrolledWindow* _tmp10_ = NULL;
	GtkActionBar* _tmp11_ = NULL;
	GtkActionBar* _tmp12_ = NULL;
	GtkGrid* _tmp13_ = NULL;
	GtkActionBar* _tmp14_ = NULL;
	GtkButton* _tmp15_ = NULL;
	GtkButton* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	GtkButton* _tmp18_ = NULL;
	GtkButton* _tmp19_ = NULL;
	GtkButton* _tmp20_ = NULL;
	GtkButton* _tmp21_ = NULL;
	GtkButton* _tmp22_ = NULL;
	GtkActionBar* _tmp23_ = NULL;
	GtkButton* _tmp24_ = NULL;
	ClocksIconView* _tmp25_ = NULL;
	ClocksIconView* _tmp26_ = NULL;
	GtkGrid* _tmp27_ = NULL;
	GtkGrid* _tmp28_ = NULL;
	parent_class = G_OBJECT_CLASS (clocks_content_view_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CLOCKS_TYPE_CONTENT_VIEW, ClocksContentView);
	_data7_ = g_slice_new0 (Block7Data);
	_data7_->_ref_count_ = 1;
	_data7_->self = g_object_ref (self);
	_tmp0_ = clocks_icon_view_new ();
	g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->priv->icon_view);
	self->priv->icon_view = _tmp0_;
	_tmp1_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
	g_object_ref_sink (_tmp1_);
	scrolled_window = _tmp1_;
	_tmp2_ = scrolled_window;
	_tmp3_ = self->priv->icon_view;
	gtk_container_add ((GtkContainer*) _tmp2_, (GtkWidget*) _tmp3_);
	_tmp4_ = scrolled_window;
	gtk_widget_set_hexpand ((GtkWidget*) _tmp4_, TRUE);
	_tmp5_ = scrolled_window;
	gtk_widget_set_vexpand ((GtkWidget*) _tmp5_, TRUE);
	_tmp6_ = scrolled_window;
	gtk_widget_set_halign ((GtkWidget*) _tmp6_, GTK_ALIGN_FILL);
	_tmp7_ = scrolled_window;
	gtk_widget_set_valign ((GtkWidget*) _tmp7_, GTK_ALIGN_FILL);
	_tmp8_ = (GtkGrid*) gtk_grid_new ();
	g_object_ref_sink (_tmp8_);
	_g_object_unref0 (self->priv->grid);
	self->priv->grid = _tmp8_;
	_tmp9_ = self->priv->grid;
	_tmp10_ = scrolled_window;
	gtk_grid_attach (_tmp9_, (GtkWidget*) _tmp10_, 0, 0, 1, 1);
	_tmp11_ = (GtkActionBar*) gtk_action_bar_new ();
	g_object_ref_sink (_tmp11_);
	_data7_->action_bar = _tmp11_;
	_tmp12_ = _data7_->action_bar;
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp12_, TRUE);
	_tmp13_ = self->priv->grid;
	_tmp14_ = _data7_->action_bar;
	gtk_grid_attach (_tmp13_, (GtkWidget*) _tmp14_, 0, 1, 1, 1);
	_tmp15_ = (GtkButton*) gtk_button_new ();
	g_object_ref_sink (_tmp15_);
	_g_object_unref0 (self->priv->delete_button);
	self->priv->delete_button = _tmp15_;
	_tmp16_ = self->priv->delete_button;
	_tmp17_ = _ ("Delete");
	gtk_button_set_label (_tmp16_, _tmp17_);
	_tmp18_ = self->priv->delete_button;
	gtk_widget_set_visible ((GtkWidget*) _tmp18_, TRUE);
	_tmp19_ = self->priv->delete_button;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp19_, FALSE);
	_tmp20_ = self->priv->delete_button;
	gtk_widget_set_halign ((GtkWidget*) _tmp20_, GTK_ALIGN_END);
	_tmp21_ = self->priv->delete_button;
	gtk_widget_set_hexpand ((GtkWidget*) _tmp21_, TRUE);
	_tmp22_ = self->priv->delete_button;
	g_signal_connect_object (_tmp22_, "clicked", (GCallback) __clocks_content_view___lambda20__gtk_button_clicked, self, 0);
	_tmp23_ = _data7_->action_bar;
	_tmp24_ = self->priv->delete_button;
	gtk_action_bar_pack_end (_tmp23_, (GtkWidget*) _tmp24_);
	_tmp25_ = self->priv->icon_view;
	g_signal_connect_data ((GObject*) _tmp25_, "notify::mode", (GCallback) __clocks_content_view___lambda21__g_object_notify, block7_data_ref (_data7_), (GClosureNotify) block7_data_unref, 0);
	_tmp26_ = self->priv->icon_view;
	g_signal_connect_object ((GtkIconView*) _tmp26_, "item-activated", (GCallback) __clocks_content_view___lambda22__gtk_icon_view_item_activated, self, 0);
	_tmp27_ = self->priv->grid;
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp27_);
	_tmp28_ = self->priv->grid;
	gtk_widget_show_all ((GtkWidget*) _tmp28_);
	_g_object_unref0 (scrolled_window);
	block7_data_unref (_data7_);
	_data7_ = NULL;
	return obj;
}


static void clocks_content_view_class_init (ClocksContentViewClass * klass) {
	clocks_content_view_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ClocksContentViewPrivate));
	G_OBJECT_CLASS (klass)->get_property = _vala_clocks_content_view_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_clocks_content_view_set_property;
	G_OBJECT_CLASS (klass)->constructor = clocks_content_view_constructor;
	G_OBJECT_CLASS (klass)->finalize = clocks_content_view_finalize;
	g_signal_new ("item_activated", CLOCKS_TYPE_CONTENT_VIEW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, CLOCKS_TYPE_CONTENT_ITEM);
}


static void clocks_content_view_instance_init (ClocksContentView * self) {
	self->priv = CLOCKS_CONTENT_VIEW_GET_PRIVATE (self);
}


static void clocks_content_view_finalize (GObject* obj) {
	ClocksContentView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CLOCKS_TYPE_CONTENT_VIEW, ClocksContentView);
	_g_object_unref0 (self->priv->model);
	_g_object_unref0 (self->priv->icon_view);
	_g_object_unref0 (self->priv->select_button);
	_g_object_unref0 (self->priv->cancel_button);
	_g_object_unref0 (self->priv->selection_menubutton);
	_g_object_unref0 (self->priv->grid);
	_g_object_unref0 (self->priv->delete_button);
	_g_object_unref0 (self->priv->header_bar);
	G_OBJECT_CLASS (clocks_content_view_parent_class)->finalize (obj);
}


GType clocks_content_view_get_type (void) {
	static volatile gsize clocks_content_view_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_content_view_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ClocksContentViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) clocks_content_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ClocksContentView), 0, (GInstanceInitFunc) clocks_content_view_instance_init, NULL };
		GType clocks_content_view_type_id;
		clocks_content_view_type_id = g_type_register_static (gtk_bin_get_type (), "ClocksContentView", &g_define_type_info, 0);
		g_once_init_leave (&clocks_content_view_type_id__volatile, clocks_content_view_type_id);
	}
	return clocks_content_view_type_id__volatile;
}


static void _vala_clocks_content_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ClocksContentView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_CONTENT_VIEW, ClocksContentView);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_clocks_content_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ClocksContentView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_CONTENT_VIEW, ClocksContentView);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


GType clocks_am_pm_toggle_button_am_pm_get_type (void) {
	static volatile gsize clocks_am_pm_toggle_button_am_pm_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_am_pm_toggle_button_am_pm_type_id__volatile)) {
		static const GEnumValue values[] = {{CLOCKS_AM_PM_TOGGLE_BUTTON_AM_PM_AM, "CLOCKS_AM_PM_TOGGLE_BUTTON_AM_PM_AM", "am"}, {CLOCKS_AM_PM_TOGGLE_BUTTON_AM_PM_PM, "CLOCKS_AM_PM_TOGGLE_BUTTON_AM_PM_PM", "pm"}, {0, NULL, NULL}};
		GType clocks_am_pm_toggle_button_am_pm_type_id;
		clocks_am_pm_toggle_button_am_pm_type_id = g_enum_register_static ("ClocksAmPmToggleButtonAmPm", values);
		g_once_init_leave (&clocks_am_pm_toggle_button_am_pm_type_id__volatile, clocks_am_pm_toggle_button_am_pm_type_id);
	}
	return clocks_am_pm_toggle_button_am_pm_type_id__volatile;
}


static void __lambda41_ (ClocksAmPmToggleButton* self) {
	ClocksAmPmToggleButtonAmPm _tmp0_ = 0;
	ClocksAmPmToggleButtonAmPm _tmp1_ = 0;
	ClocksAmPmToggleButtonAmPm _tmp2_ = 0;
	_tmp1_ = clocks_am_pm_toggle_button_get_choice (self);
	_tmp2_ = _tmp1_;
	if (_tmp2_ == CLOCKS_AM_PM_TOGGLE_BUTTON_AM_PM_AM) {
		_tmp0_ = CLOCKS_AM_PM_TOGGLE_BUTTON_AM_PM_PM;
	} else {
		_tmp0_ = CLOCKS_AM_PM_TOGGLE_BUTTON_AM_PM_AM;
	}
	clocks_am_pm_toggle_button_set_choice (self, _tmp0_);
}


static void ___lambda41__gtk_button_clicked (GtkButton* _sender, gpointer self) {
	__lambda41_ ((ClocksAmPmToggleButton*) self);
}


ClocksAmPmToggleButton* clocks_am_pm_toggle_button_construct (GType object_type) {
	ClocksAmPmToggleButton * self = NULL;
	GtkStack* _tmp0_ = NULL;
	GtkStyleContext* _tmp1_ = NULL;
	gchar* str = NULL;
	GDateTime* _tmp2_ = NULL;
	GDateTime* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	GtkLabel* _tmp7_ = NULL;
	GDateTime* _tmp8_ = NULL;
	GDateTime* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	GtkLabel* _tmp12_ = NULL;
	GtkStack* _tmp13_ = NULL;
	GtkLabel* _tmp14_ = NULL;
	GtkStack* _tmp15_ = NULL;
	GtkLabel* _tmp16_ = NULL;
	GtkStack* _tmp17_ = NULL;
	GtkStack* _tmp18_ = NULL;
	GtkLabel* _tmp19_ = NULL;
	self = (ClocksAmPmToggleButton*) g_object_new (object_type, NULL);
	_tmp0_ = (GtkStack*) gtk_stack_new ();
	g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->priv->stack);
	self->priv->stack = _tmp0_;
	_tmp1_ = gtk_widget_get_style_context ((GtkWidget*) self);
	gtk_style_context_add_class (_tmp1_, "clocks-ampm-toggle-button");
	_tmp2_ = g_date_time_new_utc (1, 1, 1, 0, 0, (gdouble) 0);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_date_time_format (_tmp3_, "%p");
	_tmp5_ = _tmp4_;
	_g_date_time_unref0 (_tmp3_);
	str = _tmp5_;
	_tmp6_ = str;
	_tmp7_ = (GtkLabel*) gtk_label_new (_tmp6_);
	g_object_ref_sink (_tmp7_);
	_g_object_unref0 (self->priv->am_label);
	self->priv->am_label = _tmp7_;
	_tmp8_ = g_date_time_new_utc (1, 1, 1, 12, 0, (gdouble) 0);
	_tmp9_ = _tmp8_;
	_tmp10_ = g_date_time_format (_tmp9_, "%p");
	_g_free0 (str);
	str = _tmp10_;
	_g_date_time_unref0 (_tmp9_);
	_tmp11_ = str;
	_tmp12_ = (GtkLabel*) gtk_label_new (_tmp11_);
	g_object_ref_sink (_tmp12_);
	_g_object_unref0 (self->priv->pm_label);
	self->priv->pm_label = _tmp12_;
	_tmp13_ = self->priv->stack;
	_tmp14_ = self->priv->am_label;
	gtk_container_add ((GtkContainer*) _tmp13_, (GtkWidget*) _tmp14_);
	_tmp15_ = self->priv->stack;
	_tmp16_ = self->priv->pm_label;
	gtk_container_add ((GtkContainer*) _tmp15_, (GtkWidget*) _tmp16_);
	_tmp17_ = self->priv->stack;
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp17_);
	g_signal_connect_object ((GtkButton*) self, "clicked", (GCallback) ___lambda41__gtk_button_clicked, self, 0);
	clocks_am_pm_toggle_button_set_choice (self, CLOCKS_AM_PM_TOGGLE_BUTTON_AM_PM_AM);
	_tmp18_ = self->priv->stack;
	_tmp19_ = self->priv->am_label;
	gtk_stack_set_visible_child (_tmp18_, (GtkWidget*) _tmp19_);
	gtk_widget_show_all ((GtkWidget*) self);
	_g_free0 (str);
	return self;
}


ClocksAmPmToggleButton* clocks_am_pm_toggle_button_new (void) {
	return clocks_am_pm_toggle_button_construct (CLOCKS_TYPE_AM_PM_TOGGLE_BUTTON);
}


ClocksAmPmToggleButtonAmPm clocks_am_pm_toggle_button_get_choice (ClocksAmPmToggleButton* self) {
	ClocksAmPmToggleButtonAmPm result;
	ClocksAmPmToggleButtonAmPm _tmp0_ = 0;
	g_return_val_if_fail (self != NULL, 0);
	_tmp0_ = self->priv->_choice;
	result = _tmp0_;
	return result;
}


void clocks_am_pm_toggle_button_set_choice (ClocksAmPmToggleButton* self, ClocksAmPmToggleButtonAmPm value) {
	ClocksAmPmToggleButtonAmPm _tmp0_ = 0;
	ClocksAmPmToggleButtonAmPm _tmp1_ = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_choice;
	_tmp1_ = value;
	if (_tmp0_ != _tmp1_) {
		ClocksAmPmToggleButtonAmPm _tmp2_ = 0;
		GtkLabel* _tmp3_ = NULL;
		ClocksAmPmToggleButtonAmPm _tmp4_ = 0;
		GtkStack* _tmp7_ = NULL;
		_tmp2_ = value;
		self->priv->_choice = _tmp2_;
		_tmp4_ = self->priv->_choice;
		if (_tmp4_ == CLOCKS_AM_PM_TOGGLE_BUTTON_AM_PM_AM) {
			GtkLabel* _tmp5_ = NULL;
			_tmp5_ = self->priv->am_label;
			_tmp3_ = _tmp5_;
		} else {
			GtkLabel* _tmp6_ = NULL;
			_tmp6_ = self->priv->pm_label;
			_tmp3_ = _tmp6_;
		}
		_tmp7_ = self->priv->stack;
		gtk_stack_set_visible_child (_tmp7_, (GtkWidget*) _tmp3_);
	}
	g_object_notify ((GObject *) self, "choice");
}


static void clocks_am_pm_toggle_button_class_init (ClocksAmPmToggleButtonClass * klass) {
	clocks_am_pm_toggle_button_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ClocksAmPmToggleButtonPrivate));
	G_OBJECT_CLASS (klass)->get_property = _vala_clocks_am_pm_toggle_button_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_clocks_am_pm_toggle_button_set_property;
	G_OBJECT_CLASS (klass)->finalize = clocks_am_pm_toggle_button_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), CLOCKS_AM_PM_TOGGLE_BUTTON_CHOICE, g_param_spec_enum ("choice", "choice", "choice", CLOCKS_AM_PM_TOGGLE_BUTTON_TYPE_AM_PM, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void clocks_am_pm_toggle_button_instance_init (ClocksAmPmToggleButton * self) {
	self->priv = CLOCKS_AM_PM_TOGGLE_BUTTON_GET_PRIVATE (self);
}


static void clocks_am_pm_toggle_button_finalize (GObject* obj) {
	ClocksAmPmToggleButton * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CLOCKS_TYPE_AM_PM_TOGGLE_BUTTON, ClocksAmPmToggleButton);
	_g_object_unref0 (self->priv->stack);
	_g_object_unref0 (self->priv->am_label);
	_g_object_unref0 (self->priv->pm_label);
	G_OBJECT_CLASS (clocks_am_pm_toggle_button_parent_class)->finalize (obj);
}


GType clocks_am_pm_toggle_button_get_type (void) {
	static volatile gsize clocks_am_pm_toggle_button_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_am_pm_toggle_button_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ClocksAmPmToggleButtonClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) clocks_am_pm_toggle_button_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ClocksAmPmToggleButton), 0, (GInstanceInitFunc) clocks_am_pm_toggle_button_instance_init, NULL };
		GType clocks_am_pm_toggle_button_type_id;
		clocks_am_pm_toggle_button_type_id = g_type_register_static (gtk_button_get_type (), "ClocksAmPmToggleButton", &g_define_type_info, 0);
		g_once_init_leave (&clocks_am_pm_toggle_button_type_id__volatile, clocks_am_pm_toggle_button_type_id);
	}
	return clocks_am_pm_toggle_button_type_id__volatile;
}


static void _vala_clocks_am_pm_toggle_button_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ClocksAmPmToggleButton * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_AM_PM_TOGGLE_BUTTON, ClocksAmPmToggleButton);
	switch (property_id) {
		case CLOCKS_AM_PM_TOGGLE_BUTTON_CHOICE:
		g_value_set_enum (value, clocks_am_pm_toggle_button_get_choice (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_clocks_am_pm_toggle_button_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ClocksAmPmToggleButton * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CLOCKS_TYPE_AM_PM_TOGGLE_BUTTON, ClocksAmPmToggleButton);
	switch (property_id) {
		case CLOCKS_AM_PM_TOGGLE_BUTTON_CHOICE:
		clocks_am_pm_toggle_button_set_choice (self, g_value_get_enum (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static gint clocks_analog_frame_calculate_diameter (ClocksAnalogFrame* self) {
	gint result = 0;
	gint ret = 0;
	GtkWidget* child = NULL;
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GtkWidget* _tmp3_ = NULL;
	g_return_val_if_fail (self != NULL, 0);
	ret = 2 * CLOCKS_ANALOG_FRAME_RADIUS_PAD;
	_tmp0_ = gtk_bin_get_child ((GtkBin*) self);
	_tmp1_ = _g_object_ref0 (_tmp0_);
	child = _tmp1_;
	_tmp3_ = child;
	if (_tmp3_ != NULL) {
		GtkWidget* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		gboolean _tmp6_ = FALSE;
		_tmp4_ = child;
		_tmp5_ = gtk_widget_get_visible (_tmp4_);
		_tmp6_ = _tmp5_;
		_tmp2_ = _tmp6_;
	} else {
		_tmp2_ = FALSE;
	}
	if (_tmp2_) {
		gint w = 0;
		gint h = 0;
		GtkWidget* _tmp7_ = NULL;
		gint _tmp8_ = 0;
		GtkWidget* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		gint _tmp11_ = 0;
		gint _tmp12_ = 0;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		gint _tmp15_ = 0;
		gdouble _tmp16_ = 0.0;
		_tmp7_ = child;
		gtk_widget_get_preferred_width (_tmp7_, &_tmp8_, NULL);
		w = _tmp8_;
		_tmp9_ = child;
		gtk_widget_get_preferred_height (_tmp9_, &_tmp10_, NULL);
		h = _tmp10_;
		_tmp11_ = ret;
		_tmp12_ = w;
		_tmp13_ = w;
		_tmp14_ = h;
		_tmp15_ = h;
		_tmp16_ = sqrt ((gdouble) ((_tmp12_ * _tmp13_) + (_tmp14_ * _tmp15_)));
		ret = _tmp11_ + ((gint) _tmp16_);
	}
	result = ret;
	_g_object_unref0 (child);
	return result;
}


static void clocks_analog_frame_real_get_preferred_width (GtkWidget* base, gint* min_w, gint* natural_w) {
	ClocksAnalogFrame * self;
	gint _vala_min_w = 0;
	gint _vala_natural_w = 0;
	gint d = 0;
	gint _tmp0_ = 0;
	self = (ClocksAnalogFrame*) base;
	_tmp0_ = clocks_analog_frame_calculate_diameter (self);
	d = _tmp0_;
	_vala_min_w = d;
	_vala_natural_w = d;
	if (min_w) {
		*min_w = _vala_min_w;
	}
	if (natural_w) {
		*natural_w = _vala_natural_w;
	}
}


static void clocks_analog_frame_real_get_preferred_height (GtkWidget* base, gint* min_h, gint* natural_h) {
	ClocksAnalogFrame * self;
	gint _vala_min_h = 0;
	gint _vala_natural_h = 0;
	gint d = 0;
	gint _tmp0_ = 0;
	self = (ClocksAnalogFrame*) base;
	_tmp0_ = clocks_analog_frame_calculate_diameter (self);
	d = _tmp0_;
	_vala_min_h = d;
	_vala_natural_h = d;
	if (min_h) {
		*min_h = _vala_min_h;
	}
	if (natural_h) {
		*natural_h = _vala_natural_h;
	}
}


static void clocks_analog_frame_real_size_allocate (GtkWidget* base, GtkAllocation* allocation) {
	ClocksAnalogFrame * self;
	GtkAllocation _tmp0_ = {0};
	self = (ClocksAnalogFrame*) base;
	g_return_if_fail (allocation != NULL);
	_tmp0_ = *allocation;
	GTK_WIDGET_CLASS (clocks_analog_frame_parent_class)->size_allocate ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_bin_get_type (), GtkBin), &_tmp0_);
}


static gboolean clocks_analog_frame_real_draw (GtkWidget* base, cairo_t* cr) {
	ClocksAnalogFrame * self;
	gboolean result = FALSE;
	GtkStyleContext* context = NULL;
	GtkStyleContext* _tmp0_ = NULL;
	GtkStyleContext* _tmp1_ = NULL;
	GtkAllocation allocation = {0};
	GtkAllocation _tmp2_ = {0};
	gint center_x = 0;
	GtkAllocation _tmp3_ = {0};
	gint _tmp4_ = 0;
	gint center_y = 0;
	GtkAllocation _tmp5_ = {0};
	gint _tmp6_ = 0;
	gint radius = 0;
	gint _tmp7_ = 0;
	cairo_t* _tmp8_ = NULL;
	cairo_t* _tmp9_ = NULL;
	GdkRGBA color = {0};
	GtkStateFlags _tmp10_ = 0;
	GdkRGBA _tmp11_ = {0};
	cairo_t* _tmp12_ = NULL;
	cairo_t* _tmp13_ = NULL;
	GdkRGBA _tmp14_ = {0};
	cairo_t* _tmp15_ = NULL;
	cairo_t* _tmp16_ = NULL;
	cairo_t* _tmp17_ = NULL;
	cairo_t* _tmp18_ = NULL;
	cairo_t* _tmp19_ = NULL;
	gboolean _tmp20_ = FALSE;
	self = (ClocksAnalogFrame*) base;
	g_return_val_if_fail (cr != NULL, FALSE);
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
	_tmp1_ = _g_object_ref0 (_tmp0_);
	context = _tmp1_;
	gtk_widget_get_allocation ((GtkWidget*) self, &_tmp2_);
	allocation = _tmp2_;
	_tmp3_ = allocation;
	_tmp4_ = _tmp3_.width;
	center_x = _tmp4_ / 2;
	_tmp5_ = allocation;
	_tmp6_ = _tmp5_.height;
	center_y = _tmp6_ / 2;
	_tmp7_ = clocks_analog_frame_calculate_diameter (self);
	radius = _tmp7_ / 2;
	_tmp8_ = cr;
	cairo_save (_tmp8_);
	_tmp9_ = cr;
	cairo_move_to (_tmp9_, (gdouble) (center_x + radius), (gdouble) center_y);
	gtk_style_context_save (context);
	gtk_style_context_add_class (context, "clocks-analog-frame");
	gtk_style_context_save (context);
	gtk_style_context_add_class (context, GTK_STYLE_CLASS_TROUGH);
	_tmp10_ = gtk_style_context_get_state (context);
	gtk_style_context_get_color (context, _tmp10_, &_tmp11_);
	color = _tmp11_;
	_tmp12_ = cr;
	cairo_set_line_width (_tmp12_, (gdouble) CLOCKS_ANALOG_FRAME_LINE_WIDTH);
	_tmp13_ = cr;
	_tmp14_ = color;
	gdk_cairo_set_source_rgba (_tmp13_, &_tmp14_);
	_tmp15_ = cr;
	cairo_arc (_tmp15_, (gdouble) center_x, (gdouble) center_y, (gdouble) (radius - (CLOCKS_ANALOG_FRAME_LINE_WIDTH / 2)), (gdouble) 0, 2 * G_PI);
	_tmp16_ = cr;
	cairo_stroke (_tmp16_);
	gtk_style_context_restore (context);
	_tmp17_ = cr;
	clocks_analog_frame_draw_progress (self, _tmp17_, center_x, center_y, radius);
	gtk_style_context_restore (context);
	_tmp18_ = cr;
	cairo_restore (_tmp18_);
	_tmp19_ = cr;
	_tmp20_ = GTK_WIDGET_CLASS (clocks_analog_frame_parent_class)->draw ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_bin_get_type (), GtkBin), _tmp19_);
	result = _tmp20_;
	_g_object_unref0 (context);
	return result;
}


static void clocks_analog_frame_real_draw_progress (ClocksAnalogFrame* self, cairo_t* cr, gint center_x, gint center_y, gint radius) {
	g_return_if_fail (cr != NULL);
}


void clocks_analog_frame_draw_progress (ClocksAnalogFrame* self, cairo_t* cr, gint center_x, gint center_y, gint radius) {
	g_return_if_fail (self != NULL);
	CLOCKS_ANALOG_FRAME_GET_CLASS (self)->draw_progress (self, cr, center_x, center_y, radius);
}


ClocksAnalogFrame* clocks_analog_frame_construct (GType object_type) {
	ClocksAnalogFrame * self = NULL;
	self = (ClocksAnalogFrame*) g_object_new (object_type, NULL);
	return self;
}


ClocksAnalogFrame* clocks_analog_frame_new (void) {
	return clocks_analog_frame_construct (CLOCKS_TYPE_ANALOG_FRAME);
}


static void clocks_analog_frame_class_init (ClocksAnalogFrameClass * klass) {
	clocks_analog_frame_parent_class = g_type_class_peek_parent (klass);
	((GtkWidgetClass *) klass)->get_preferred_width = clocks_analog_frame_real_get_preferred_width;
	((GtkWidgetClass *) klass)->get_preferred_height = clocks_analog_frame_real_get_preferred_height;
	((GtkWidgetClass *) klass)->size_allocate = clocks_analog_frame_real_size_allocate;
	((GtkWidgetClass *) klass)->draw = clocks_analog_frame_real_draw;
	((ClocksAnalogFrameClass *) klass)->draw_progress = clocks_analog_frame_real_draw_progress;
}


static void clocks_analog_frame_instance_init (ClocksAnalogFrame * self) {
}


GType clocks_analog_frame_get_type (void) {
	static volatile gsize clocks_analog_frame_type_id__volatile = 0;
	if (g_once_init_enter (&clocks_analog_frame_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ClocksAnalogFrameClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) clocks_analog_frame_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ClocksAnalogFrame), 0, (GInstanceInitFunc) clocks_analog_frame_instance_init, NULL };
		GType clocks_analog_frame_type_id;
		clocks_analog_frame_type_id = g_type_register_static (gtk_bin_get_type (), "ClocksAnalogFrame", &g_define_type_info, 0);
		g_once_init_leave (&clocks_analog_frame_type_id__volatile, clocks_analog_frame_type_id);
	}
	return clocks_analog_frame_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



